(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[5443],{61120:function(A){var e;e=function(){"use strict";/*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */ var A,e,t,r,B,n=function(A,e){return(n=Object.setPrototypeOf||({__proto__:[]})instanceof Array&&function(A,e){A.__proto__=e}||function(A,e){for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&(A[t]=e[t])})(A,e)};function s(A,e){if("function"!=typeof e&&null!==e)throw TypeError("Class extends value "+String(e)+" is not a constructor or null");function t(){this.constructor=A}n(A,e),A.prototype=null===e?Object.create(e):(t.prototype=e.prototype,new t)}var o=function(){return(o=Object.assign||function(A){for(var e,t=1,r=arguments.length;t<r;t++)for(var B in e=arguments[t])Object.prototype.hasOwnProperty.call(e,B)&&(A[B]=e[B]);return A}).apply(this,arguments)};function i(A,e,t,r){return new(t||(t=Promise))(function(B,n){function s(A){try{i(r.next(A))}catch(e){n(e)}}function o(A){try{i(r.throw(A))}catch(e){n(e)}}function i(A){var e;A.done?B(A.value):((e=A.value)instanceof t?e:new t(function(A){A(e)})).then(s,o)}i((r=r.apply(A,e||[])).next())})}function Q(A,e){var t,r,B,n,s={label:0,sent:function(){if(1&B[0])throw B[1];return B[1]},trys:[],ops:[]};return n={next:o(0),throw:o(1),return:o(2)},"function"==typeof Symbol&&(n[Symbol.iterator]=function(){return this}),n;function o(n){return function(o){return function(n){if(t)throw TypeError("Generator is already executing.");for(;s;)try{if(t=1,r&&(B=2&n[0]?r.return:n[0]?r.throw||((B=r.return)&&B.call(r),0):r.next)&&!(B=B.call(r,n[1])).done)return B;switch(r=0,B&&(n=[2&n[0],B.value]),n[0]){case 0:case 1:B=n;break;case 4:return s.label++,{value:n[1],done:!1};case 5:s.label++,r=n[1],n=[0];continue;case 7:n=s.ops.pop(),s.trys.pop();continue;default:if(!(B=(B=s.trys).length>0&&B[B.length-1])&&(6===n[0]||2===n[0])){s=0;continue}if(3===n[0]&&(!B||n[1]>B[0]&&n[1]<B[3])){s.label=n[1];break}if(6===n[0]&&s.label<B[1]){s.label=B[1],B=n;break}if(B&&s.label<B[2]){s.label=B[2],s.ops.push(n);break}B[2]&&s.ops.pop(),s.trys.pop();continue}n=e.call(A,s)}catch(o){n=[6,o],r=0}finally{t=B=0}if(5&n[0])throw n[1];return{value:n[0]?n[1]:void 0,done:!0}}([n,o])}}}function a(A,e,t){if(t||2===arguments.length)for(var r,B=0,n=e.length;B<n;B++)!r&&B in e||(r||(r=Array.prototype.slice.call(e,0,B)),r[B]=e[B]);return A.concat(r||e)}for(var c=function(){function A(A,e,t,r){this.left=A,this.top=e,this.width=t,this.height=r}return A.prototype.add=function(e,t,r,B){return new A(this.left+e,this.top+t,this.width+r,this.height+B)},A.fromClientRect=function(e,t){return new A(t.left+e.windowBounds.left,t.top+e.windowBounds.top,t.width,t.height)},A.fromDOMRectList=function(e,t){var r=Array.from(t).find(function(A){return 0!==A.width});return r?new A(r.left+e.windowBounds.left,r.top+e.windowBounds.top,r.width,r.height):A.EMPTY},A.EMPTY=new A(0,0,0,0),A}(),g=function(A,e){return c.fromClientRect(A,e.getBoundingClientRect())},w=function(A){var e=A.body,t=A.documentElement;if(!e||!t)throw Error("Unable to get document size");var r=Math.max(Math.max(e.scrollWidth,t.scrollWidth),Math.max(e.offsetWidth,t.offsetWidth),Math.max(e.clientWidth,t.clientWidth)),B=Math.max(Math.max(e.scrollHeight,t.scrollHeight),Math.max(e.offsetHeight,t.offsetHeight),Math.max(e.clientHeight,t.clientHeight));return new c(0,0,r,B)},l=function(A){for(var e=[],t=0,r=A.length;t<r;){var B=A.charCodeAt(t++);if(B>=55296&&B<=56319&&t<r){var n=A.charCodeAt(t++);(64512&n)==56320?e.push(((1023&B)<<10)+(1023&n)+65536):(e.push(B),t--)}else e.push(B)}return e},u=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];if(String.fromCodePoint)return String.fromCodePoint.apply(String,A);var t=A.length;if(!t)return"";for(var r=[],B=-1,n="";++B<t;){var s=A[B];s<=65535?r.push(s):(s-=65536,r.push((s>>10)+55296,s%1024+56320)),(B+1===t||r.length>16384)&&(n+=String.fromCharCode.apply(String,r),r.length=0)}return n},U="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",C="undefined"==typeof Uint8Array?[]:new Uint8Array(256),F=0;F<U.length;F++)C[U.charCodeAt(F)]=F;for(var h="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",d="undefined"==typeof Uint8Array?[]:new Uint8Array(256),f=0;f<h.length;f++)d[h.charCodeAt(f)]=f;for(var H=2112,p=function(A,e,t){return A.slice?A.slice(e,t):new Uint16Array(Array.prototype.slice.call(A,e,t))},E=function(){function A(A,e,t,r,B,n){this.initialValue=A,this.errorValue=e,this.highStart=t,this.highValueIndex=r,this.index=B,this.data=n}return A.prototype.get=function(A){var e;if(A>=0){if(A<55296||A>56319&&A<=65535)return e=((e=this.index[A>>5])<<2)+(31&A),this.data[e];if(A<=65535)return e=((e=this.index[2048+(A-55296>>5)])<<2)+(31&A),this.data[e];if(A<this.highStart)return e=H-32+(A>>11),e=this.index[e],e+=A>>5&63,e=((e=this.index[e])<<2)+(31&A),this.data[e];if(A<=1114111)return this.data[this.highValueIndex]}return this.errorValue},A}(),I="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",y="undefined"==typeof Uint8Array?[]:new Uint8Array(256),K=0;K<I.length;K++)y[I.charCodeAt(K)]=K;var m,L,v,b,D,x,M,S,T,G=[9001,65288],O=(v=Array.isArray(L=function(A){var e,t,r,B,n,s=.75*A.length,o=A.length,i=0;"="===A[A.length-1]&&(s--,"="===A[A.length-2]&&s--);var Q="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof Uint8Array&&void 0!==Uint8Array.prototype.slice?new ArrayBuffer(s):Array(s),a=Array.isArray(Q)?Q:new Uint8Array(Q);for(e=0;e<o;e+=4)t=d[A.charCodeAt(e)],r=d[A.charCodeAt(e+1)],B=d[A.charCodeAt(e+2)],n=d[A.charCodeAt(e+3)],a[i++]=t<<2|r>>4,a[i++]=(15&r)<<4|B>>2,a[i++]=(3&B)<<6|63&n;return Q}(" "))?function(A){for(var e=A.length,t=[],r=0;r<e;r+=4)t.push(A[r+3]<<24|A[r+2]<<16|A[r+1]<<8|A[r]);return t}(L):new Uint32Array(L),b=Array.isArray(L)?function(A){for(var e=A.length,t=[],r=0;r<e;r+=2)t.push(A[r+1]<<8|A[r]);return t}(L):new Uint16Array(L),D=p(b,12,v[4]/2),T=2===v[5]?p(b,(24+v[4])/2):(M=Math.ceil((24+v[4])/4),v.slice?v.slice(M,S):new Uint32Array(Array.prototype.slice.call(v,M,S))),new E(v[0],v[1],v[2],v[3],D,T)),V=[30,36],k=[1,2,3,5],R=[10,8],N=[27,26],P=k.concat(R),X=[38,39,40,34,35],J=[15,13],Y=function(A,e){void 0===e&&(e="strict");var t=[],r=[],B=[];return A.forEach(function(A,n){var s=O.get(A);if(s>50?(B.push(!0),s-=50):B.push(!1),-1!==["normal","auto","loose"].indexOf(e)&&-1!==[8208,8211,12316,12448].indexOf(A))return r.push(n),t.push(16);if(4===s||11===s){if(0===n)return r.push(n),t.push(30);var o=t[n-1];return -1===P.indexOf(o)?(r.push(r[n-1]),t.push(o)):(r.push(n),t.push(30))}return(r.push(n),31===s)?t.push("strict"===e?21:37):42===s||29===s?t.push(30):43===s?A>=131072&&A<=196605||A>=196608&&A<=262141?t.push(37):t.push(30):void t.push(s)}),[r,t,B]},W=function(A,e,t,r){var B=r[t];if(Array.isArray(A)?-1!==A.indexOf(B):A===B)for(var n=t;n<=r.length;){var s=r[++n];if(s===e)return!0;if(10!==s)break}if(10===B)for(var n=t;n>0;){var o=r[--n];if(Array.isArray(A)?-1!==A.indexOf(o):A===o)for(var i=t;i<=r.length;){var s=r[++i];if(s===e)return!0;if(10!==s)break}if(10!==o)break}return!1},Z=function(A,e){for(var t=A;t>=0;){var r=e[t];if(10!==r)return r;t--}return 0},_=function(A,e,t,r,B){if(0===t[r])return"\xd7";var n=r-1;if(Array.isArray(B)&&!0===B[n])return"\xd7";var s=n-1,o=n+1,i=e[n],Q=s>=0?e[s]:0,a=e[o];if(2===i&&3===a)return"\xd7";if(-1!==k.indexOf(i))return"!";if(-1!==k.indexOf(a)||-1!==R.indexOf(a))return"\xd7";if(8===Z(n,e))return"\xf7";if(11===O.get(A[n])||(32===i||33===i)&&11===O.get(A[o])||7===i||7===a||9===i||-1===[10,13,15].indexOf(i)&&9===a||-1!==[17,18,19,24,28].indexOf(a)||22===Z(n,e)||W(23,22,n,e)||W([17,18],21,n,e)||W(12,12,n,e))return"\xd7";if(10===i)return"\xf7";if(23===i||23===a)return"\xd7";if(16===a||16===i)return"\xf7";if(-1!==[13,15,21].indexOf(a)||14===i||36===Q&&-1!==J.indexOf(i)||28===i&&36===a||20===a||-1!==V.indexOf(a)&&25===i||-1!==V.indexOf(i)&&25===a||27===i&&-1!==[37,32,33].indexOf(a)||-1!==[37,32,33].indexOf(i)&&26===a||-1!==V.indexOf(i)&&-1!==N.indexOf(a)||-1!==N.indexOf(i)&&-1!==V.indexOf(a)||-1!==[27,26].indexOf(i)&&(25===a||-1!==[22,15].indexOf(a)&&25===e[o+1])||-1!==[22,15].indexOf(i)&&25===a||25===i&&-1!==[25,28,24].indexOf(a))return"\xd7";if(-1!==[25,28,24,17,18].indexOf(a))for(var c=n;c>=0;){var g=e[c];if(25===g)return"\xd7";if(-1!==[28,24].indexOf(g))c--;else break}if(-1!==[27,26].indexOf(a))for(var c=-1!==[17,18].indexOf(i)?s:n;c>=0;){var g=e[c];if(25===g)return"\xd7";if(-1!==[28,24].indexOf(g))c--;else break}if(38===i&&-1!==[38,39,34,35].indexOf(a)||-1!==[39,34].indexOf(i)&&-1!==[39,40].indexOf(a)||-1!==[40,35].indexOf(i)&&40===a||-1!==X.indexOf(i)&&-1!==[20,26].indexOf(a)||-1!==X.indexOf(a)&&27===i||-1!==V.indexOf(i)&&-1!==V.indexOf(a)||24===i&&-1!==V.indexOf(a)||-1!==V.concat(25).indexOf(i)&&22===a&&-1===G.indexOf(A[o])||-1!==V.concat(25).indexOf(a)&&18===i)return"\xd7";if(41===i&&41===a){for(var w=t[n],l=1;w>0;)if(41===e[--w])l++;else break;if(l%2!=0)return"\xd7"}return 32===i&&33===a?"\xd7":"\xf7"},q=function(A,e){e||(e={lineBreak:"normal",wordBreak:"normal"});var t=Y(A,e.lineBreak),r=t[0],B=t[1],n=t[2];return("break-all"===e.wordBreak||"break-word"===e.wordBreak)&&(B=B.map(function(A){return -1!==[25,30,42].indexOf(A)?37:A})),[r,B,"keep-all"===e.wordBreak?n.map(function(e,t){return e&&A[t]>=19968&&A[t]<=40959}):void 0]},j=function(){function A(A,e,t,r){this.codePoints=A,this.required="!"===e,this.start=t,this.end=r}return A.prototype.slice=function(){return u.apply(void 0,this.codePoints.slice(this.start,this.end))},A}(),z=function(A,e){var t=l(A),r=q(t,e),B=r[0],n=r[1],s=r[2],o=t.length,i=0,Q=0;return{next:function(){if(Q>=o)return{done:!0,value:null};for(var A="\xd7";Q<o&&"\xd7"===(A=_(t,n,B,++Q,s)););if("\xd7"!==A||Q===o){var e=new j(t,A,i,Q);return i=Q,{value:e,done:!1}}return{done:!0,value:null}}}},$=function(A){return A>=48&&A<=57},AA=function(A){return $(A)||A>=65&&A<=70||A>=97&&A<=102},Ae=function(A){var e,t;return A>=97&&A<=122||A>=65&&A<=90},At=function(A){return 10===A||9===A||32===A},Ar=function(A){var e;return Ae(A)||A>=128||95===A},AB=function(A){return Ar(A)||$(A)||45===A},An=function(A,e){return 92===A&&10!==e},As=function(A,e,t){return 45===A?Ar(e)||An(e,t):!!(Ar(A)||92===A&&An(A,e))},Ao=function(A,e,t){return 43===A||45===A?!!$(e)||46===e&&$(t):46===A?$(e):$(A)},Ai=function(A){var e=0,t=1;(43===A[e]||45===A[e])&&(45===A[e]&&(t=-1),e++);for(var r=[];$(A[e]);)r.push(A[e++]);var B=r.length?parseInt(u.apply(void 0,r),10):0;46===A[e]&&e++;for(var n=[];$(A[e]);)n.push(A[e++]);var s=n.length,o=s?parseInt(u.apply(void 0,n),10):0;(69===A[e]||101===A[e])&&e++;var i=1;(43===A[e]||45===A[e])&&(45===A[e]&&(i=-1),e++);for(var Q=[];$(A[e]);)Q.push(A[e++]);var a=Q.length?parseInt(u.apply(void 0,Q),10):0;return t*(B+o*Math.pow(10,-s))*Math.pow(10,i*a)},AQ={type:2},Aa={type:3},Ac={type:4},Ag={type:13},Aw={type:8},Al={type:21},Au={type:9},AU={type:10},AC={type:11},AF={type:12},Ah={type:14},Ad={type:23},Af={type:1},AH={type:25},Ap={type:24},AE={type:26},AI={type:27},Ay={type:28},AK={type:29},Am={type:31},AL={type:32},Av=function(){function A(){this._value=[]}return A.prototype.write=function(A){this._value=this._value.concat(l(A))},A.prototype.read=function(){for(var A=[],e=this.consumeToken();e!==AL;)A.push(e),e=this.consumeToken();return A},A.prototype.consumeToken=function(){var A=this.consumeCodePoint();switch(A){case 34:return this.consumeStringToken(34);case 35:var e=this.peekCodePoint(0),t=this.peekCodePoint(1),r=this.peekCodePoint(2);if(AB(e)||An(t,r)){var B=As(e,t,r)?2:1,n=this.consumeName();return{type:5,value:n,flags:B}}break;case 36:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),Ag;break;case 39:return this.consumeStringToken(39);case 40:return AQ;case 41:return Aa;case 42:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),Ah;break;case 43:case 46:if(Ao(A,this.peekCodePoint(0),this.peekCodePoint(1)))return this.reconsumeCodePoint(A),this.consumeNumericToken();break;case 44:return Ac;case 45:var s=this.peekCodePoint(0),o=this.peekCodePoint(1);if(Ao(A,s,o))return this.reconsumeCodePoint(A),this.consumeNumericToken();if(As(A,s,o))return this.reconsumeCodePoint(A),this.consumeIdentLikeToken();if(45===s&&62===o)return this.consumeCodePoint(),this.consumeCodePoint(),Ap;break;case 47:if(42===this.peekCodePoint(0))for(this.consumeCodePoint();;){var i=this.consumeCodePoint();if(42===i&&47===(i=this.consumeCodePoint())||-1===i)return this.consumeToken()}break;case 58:return AE;case 59:return AI;case 60:if(33===this.peekCodePoint(0)&&45===this.peekCodePoint(1)&&45===this.peekCodePoint(2))return this.consumeCodePoint(),this.consumeCodePoint(),AH;break;case 64:var Q,a=this.peekCodePoint(0);if(As(a,this.peekCodePoint(1),this.peekCodePoint(2))){var n=this.consumeName();return{type:7,value:n}}break;case 91:return Ay;case 92:if(An(A,this.peekCodePoint(0)))return this.reconsumeCodePoint(A),this.consumeIdentLikeToken();break;case 93:return AK;case 61:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),Aw;break;case 123:return AC;case 125:return AF;case 117:case 85:var c=this.peekCodePoint(0),g=this.peekCodePoint(1);return 43===c&&(AA(g)||63===g)&&(this.consumeCodePoint(),this.consumeUnicodeRangeToken()),this.reconsumeCodePoint(A),this.consumeIdentLikeToken();case 124:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),Au;if(124===this.peekCodePoint(0))return this.consumeCodePoint(),Al;break;case 126:if(61===this.peekCodePoint(0))return this.consumeCodePoint(),AU;break;case -1:return AL}return At(A)?(this.consumeWhiteSpace(),Am):$(A)?(this.reconsumeCodePoint(A),this.consumeNumericToken()):Ar(A)?(this.reconsumeCodePoint(A),this.consumeIdentLikeToken()):{type:6,value:u(A)}},A.prototype.consumeCodePoint=function(){var A=this._value.shift();return void 0===A?-1:A},A.prototype.reconsumeCodePoint=function(A){this._value.unshift(A)},A.prototype.peekCodePoint=function(A){return A>=this._value.length?-1:this._value[A]},A.prototype.consumeUnicodeRangeToken=function(){for(var A=[],e=this.consumeCodePoint();AA(e)&&A.length<6;)A.push(e),e=this.consumeCodePoint();for(var t=!1;63===e&&A.length<6;)A.push(e),e=this.consumeCodePoint(),t=!0;if(t){var r=parseInt(u.apply(void 0,A.map(function(A){return 63===A?48:A})),16),B=parseInt(u.apply(void 0,A.map(function(A){return 63===A?70:A})),16);return{type:30,start:r,end:B}}var n=parseInt(u.apply(void 0,A),16);if(!(45===this.peekCodePoint(0)&&AA(this.peekCodePoint(1))))return{type:30,start:n,end:n};this.consumeCodePoint(),e=this.consumeCodePoint();for(var s=[];AA(e)&&s.length<6;)s.push(e),e=this.consumeCodePoint();var B=parseInt(u.apply(void 0,s),16);return{type:30,start:n,end:B}},A.prototype.consumeIdentLikeToken=function(){var A=this.consumeName();return"url"===A.toLowerCase()&&40===this.peekCodePoint(0)?(this.consumeCodePoint(),this.consumeUrlToken()):40===this.peekCodePoint(0)?(this.consumeCodePoint(),{type:19,value:A}):{type:20,value:A}},A.prototype.consumeUrlToken=function(){var A=[];if(this.consumeWhiteSpace(),-1===this.peekCodePoint(0))return{type:22,value:""};var e=this.peekCodePoint(0);if(39===e||34===e){var t=this.consumeStringToken(this.consumeCodePoint());return 0===t.type&&(this.consumeWhiteSpace(),-1===this.peekCodePoint(0)||41===this.peekCodePoint(0))?(this.consumeCodePoint(),{type:22,value:t.value}):(this.consumeBadUrlRemnants(),Ad)}for(;;){var r,B=this.consumeCodePoint();if(-1===B||41===B)return{type:22,value:u.apply(void 0,A)};if(At(B)){if(this.consumeWhiteSpace(),-1===this.peekCodePoint(0)||41===this.peekCodePoint(0))return this.consumeCodePoint(),{type:22,value:u.apply(void 0,A)};return this.consumeBadUrlRemnants(),Ad}if(34===B||39===B||40===B||(r=B)>=0&&r<=8||11===r||r>=14&&r<=31||127===r)return this.consumeBadUrlRemnants(),Ad;if(92===B){if(!An(B,this.peekCodePoint(0)))return this.consumeBadUrlRemnants(),Ad;A.push(this.consumeEscapedCodePoint())}else A.push(B)}},A.prototype.consumeWhiteSpace=function(){for(;At(this.peekCodePoint(0));)this.consumeCodePoint()},A.prototype.consumeBadUrlRemnants=function(){for(;;){var A=this.consumeCodePoint();if(41===A||-1===A)return;An(A,this.peekCodePoint(0))&&this.consumeEscapedCodePoint()}},A.prototype.consumeStringSlice=function(A){for(var e="";A>0;){var t=Math.min(5e4,A);e+=u.apply(void 0,this._value.splice(0,t)),A-=t}return this._value.shift(),e},A.prototype.consumeStringToken=function(A){for(var e="",t=0;;){var r=this._value[t];if(-1===r||void 0===r||r===A)return{type:0,value:e+=this.consumeStringSlice(t)};if(10===r)return this._value.splice(0,t),Af;if(92===r){var B=this._value[t+1];-1!==B&&void 0!==B&&(10===B?(e+=this.consumeStringSlice(t),t=-1,this._value.shift()):An(r,B)&&(e+=this.consumeStringSlice(t),e+=u(this.consumeEscapedCodePoint()),t=-1))}t++}},A.prototype.consumeNumber=function(){var A=[],e=4,t=this.peekCodePoint(0);for((43===t||45===t)&&A.push(this.consumeCodePoint());$(this.peekCodePoint(0));)A.push(this.consumeCodePoint());t=this.peekCodePoint(0);var r=this.peekCodePoint(1);if(46===t&&$(r))for(A.push(this.consumeCodePoint(),this.consumeCodePoint()),e=8;$(this.peekCodePoint(0));)A.push(this.consumeCodePoint());t=this.peekCodePoint(0),r=this.peekCodePoint(1);var B=this.peekCodePoint(2);if((69===t||101===t)&&((43===r||45===r)&&$(B)||$(r)))for(A.push(this.consumeCodePoint(),this.consumeCodePoint()),e=8;$(this.peekCodePoint(0));)A.push(this.consumeCodePoint());return[Ai(A),e]},A.prototype.consumeNumericToken=function(){var A,e=this.consumeNumber(),t=e[0],r=e[1],B=this.peekCodePoint(0);return As(B,this.peekCodePoint(1),this.peekCodePoint(2))?{type:15,number:t,flags:r,unit:this.consumeName()}:37===B?(this.consumeCodePoint(),{type:16,number:t,flags:r}):{type:17,number:t,flags:r}},A.prototype.consumeEscapedCodePoint=function(){var A=this.consumeCodePoint();if(AA(A)){for(var e=u(A);AA(this.peekCodePoint(0))&&e.length<6;)e+=u(this.consumeCodePoint());At(this.peekCodePoint(0))&&this.consumeCodePoint();var t,r=parseInt(e,16);return 0===r||r>=55296&&r<=57343||r>1114111?65533:r}return -1===A?65533:A},A.prototype.consumeName=function(){for(var A="";;){var e=this.consumeCodePoint();if(AB(e))A+=u(e);else{if(!An(e,this.peekCodePoint(0)))return this.reconsumeCodePoint(e),A;A+=u(this.consumeEscapedCodePoint())}}},A}(),Ab=function(){function A(A){this._tokens=A}return A.create=function(e){var t=new Av;return t.write(e),new A(t.read())},A.parseValue=function(e){return A.create(e).parseComponentValue()},A.parseValues=function(e){return A.create(e).parseComponentValues()},A.prototype.parseComponentValue=function(){for(var A=this.consumeToken();31===A.type;)A=this.consumeToken();if(32===A.type)throw SyntaxError("Error parsing CSS component value, unexpected EOF");this.reconsumeToken(A);var e=this.consumeComponentValue();do A=this.consumeToken();while(31===A.type);if(32===A.type)return e;throw SyntaxError("Error parsing CSS component value, multiple values found when expecting only one")},A.prototype.parseComponentValues=function(){for(var A=[];;){var e=this.consumeComponentValue();if(32===e.type)return A;A.push(e),A.push()}},A.prototype.consumeComponentValue=function(){var A=this.consumeToken();switch(A.type){case 11:case 28:case 2:return this.consumeSimpleBlock(A.type);case 19:return this.consumeFunction(A)}return A},A.prototype.consumeSimpleBlock=function(A){for(var e={type:A,values:[]},t=this.consumeToken();;){if(32===t.type||Ak(t,A))return e;this.reconsumeToken(t),e.values.push(this.consumeComponentValue()),t=this.consumeToken()}},A.prototype.consumeFunction=function(A){for(var e={name:A.value,values:[],type:18};;){var t=this.consumeToken();if(32===t.type||3===t.type)return e;this.reconsumeToken(t),e.values.push(this.consumeComponentValue())}},A.prototype.consumeToken=function(){var A=this._tokens.shift();return void 0===A?AL:A},A.prototype.reconsumeToken=function(A){this._tokens.unshift(A)},A}(),AD=function(A){return 15===A.type},Ax=function(A){return 17===A.type},AM=function(A){return 20===A.type},AS=function(A){return 0===A.type},AT=function(A,e){return AM(A)&&A.value===e},AG=function(A){return 31!==A.type},AO=function(A){return 31!==A.type&&4!==A.type},AV=function(A){var e=[],t=[];return A.forEach(function(A){if(4===A.type){if(0===t.length)throw Error("Error parsing function args, zero tokens for arg");e.push(t),t=[];return}31!==A.type&&t.push(A)}),t.length&&e.push(t),e},Ak=function(A,e){return 11===e&&12===A.type||28===e&&29===A.type||2===e&&3===A.type},AR=function(A){return 17===A.type||15===A.type},AN=function(A){return 16===A.type||AR(A)},AP=function(A){return A.length>1?[A[0],A[1]]:[A[0]]},AX={type:17,number:0,flags:4},AJ={type:16,number:50,flags:4},AY={type:16,number:100,flags:4},AW=function(A,e,t){var r=A[0],B=A[1];return[AZ(r,e),AZ(void 0!==B?B:r,t)]},AZ=function(A,e){if(16===A.type)return A.number/100*e;if(AD(A))switch(A.unit){case"rem":case"em":return 16*A.number}return A.number},A_="grad",Aq="turn",Aj={name:"angle",parse:function(A,e){if(15===e.type)switch(e.unit){case"deg":return Math.PI*e.number/180;case A_:return Math.PI/200*e.number;case"rad":return e.number;case Aq:return 2*Math.PI*e.number}throw Error("Unsupported angle type")}},Az=function(A){return 15===A.type&&("deg"===A.unit||A.unit===A_||"rad"===A.unit||A.unit===Aq)},A$=function(A){var e=A.filter(AM).map(function(A){return A.value}).join(" ");switch(e){case"to bottom right":case"to right bottom":case"left top":case"top left":return[AX,AX];case"to top":case"bottom":return A0(0);case"to bottom left":case"to left bottom":case"right top":case"top right":return[AX,AY];case"to right":case"left":return A0(90);case"to top left":case"to left top":case"right bottom":case"bottom right":return[AY,AY];case"to bottom":case"top":return A0(180);case"to top right":case"to right top":case"left bottom":case"bottom left":return[AY,AX];case"to left":case"right":return A0(270)}return 0},A0=function(A){return Math.PI*A/180},A4={name:"color",parse:function(A,e){if(18===e.type){var t=er[e.name];if(void 0===t)throw Error('Attempting to parse an unsupported color function "'+e.name+'"');return t(A,e.values)}if(5===e.type){if(3===e.value.length){var r=e.value.substring(0,1),B=e.value.substring(1,2),n=e.value.substring(2,3);return A3(parseInt(r+r,16),parseInt(B+B,16),parseInt(n+n,16),1)}if(4===e.value.length){var r=e.value.substring(0,1),B=e.value.substring(1,2),n=e.value.substring(2,3),s=e.value.substring(3,4);return A3(parseInt(r+r,16),parseInt(B+B,16),parseInt(n+n,16),parseInt(s+s,16)/255)}if(6===e.value.length){var r=e.value.substring(0,2),B=e.value.substring(2,4),n=e.value.substring(4,6);return A3(parseInt(r,16),parseInt(B,16),parseInt(n,16),1)}if(8===e.value.length){var r=e.value.substring(0,2),B=e.value.substring(2,4),n=e.value.substring(4,6),s=e.value.substring(6,8);return A3(parseInt(r,16),parseInt(B,16),parseInt(n,16),parseInt(s,16)/255)}}if(20===e.type){var o=en[e.value.toUpperCase()];if(void 0!==o)return o}return en.TRANSPARENT}},A1=function(A){return(255&A)==0},A2=function(A){var e=255&A,t=255&A>>8,r=255&A>>16,B=255&A>>24;return e<255?"rgba("+B+","+r+","+t+","+e/255+")":"rgb("+B+","+r+","+t+")"},A3=function(A,e,t,r){return(A<<24|e<<16|t<<8|Math.round(255*r)<<0)>>>0},A5=function(A,e){if(17===A.type)return A.number;if(16===A.type){var t=3===e?1:255;return 3===e?A.number/100*t:Math.round(A.number/100*t)}return 0},A6=function(A,e){var t=e.filter(AO);if(3===t.length){var r=t.map(A5),B=r[0],n=r[1],s=r[2];return A3(B,n,s,1)}if(4===t.length){var o=t.map(A5),B=o[0],n=o[1],s=o[2];return A3(B,n,s,o[3])}return 0};function A8(A,e,t){return(t<0&&(t+=1),t>=1&&(t-=1),t<1/6)?(e-A)*t*6+A:t<.5?e:t<2/3?(e-A)*6*(2/3-t)+A:A}var A7,A9,eA,ee,et=function(A,e){var t=e.filter(AO),r=t[0],B=t[1],n=t[2],s=t[3],o=(17===r.type?A0(r.number):Aj.parse(A,r))/(2*Math.PI),i=AN(B)?B.number/100:0,Q=AN(n)?n.number/100:0,a=void 0!==s&&AN(s)?AZ(s,1):1;if(0===i)return A3(255*Q,255*Q,255*Q,1);var c=Q<=.5?Q*(i+1):Q+i-Q*i,g=2*Q-c,w=A8(g,c,o+1/3),l=A8(g,c,o),u=A8(g,c,o-1/3);return A3(255*w,255*l,255*u,a)},er={hsl:et,hsla:et,rgb:A6,rgba:A6},eB=function(A,e){return A4.parse(A,Ab.create(e).parseComponentValue())},en={ALICEBLUE:4042850303,ANTIQUEWHITE:4209760255,AQUA:16777215,AQUAMARINE:2147472639,AZURE:4043309055,BEIGE:4126530815,BISQUE:4293182719,BLACK:255,BLANCHEDALMOND:4293643775,BLUE:65535,BLUEVIOLET:2318131967,BROWN:2771004159,BURLYWOOD:3736635391,CADETBLUE:1604231423,CHARTREUSE:2147418367,CHOCOLATE:3530104575,CORAL:4286533887,CORNFLOWERBLUE:1687547391,CORNSILK:4294499583,CRIMSON:3692313855,CYAN:16777215,DARKBLUE:35839,DARKCYAN:9145343,DARKGOLDENROD:3095837695,DARKGRAY:2846468607,DARKGREEN:6553855,DARKGREY:2846468607,DARKKHAKI:3182914559,DARKMAGENTA:2332068863,DARKOLIVEGREEN:1433087999,DARKORANGE:4287365375,DARKORCHID:2570243327,DARKRED:2332033279,DARKSALMON:3918953215,DARKSEAGREEN:2411499519,DARKSLATEBLUE:1211993087,DARKSLATEGRAY:793726975,DARKSLATEGREY:793726975,DARKTURQUOISE:13554175,DARKVIOLET:2483082239,DEEPPINK:4279538687,DEEPSKYBLUE:12582911,DIMGRAY:1768516095,DIMGREY:1768516095,DODGERBLUE:512819199,FIREBRICK:2988581631,FLORALWHITE:4294635775,FORESTGREEN:579543807,FUCHSIA:4278255615,GAINSBORO:3705462015,GHOSTWHITE:4177068031,GOLD:4292280575,GOLDENROD:3668254975,GRAY:2155905279,GREEN:8388863,GREENYELLOW:2919182335,GREY:2155905279,HONEYDEW:4043305215,HOTPINK:4285117695,INDIANRED:3445382399,INDIGO:1258324735,IVORY:4294963455,KHAKI:4041641215,LAVENDER:3873897215,LAVENDERBLUSH:4293981695,LAWNGREEN:2096890111,LEMONCHIFFON:4294626815,LIGHTBLUE:2916673279,LIGHTCORAL:4034953471,LIGHTCYAN:3774873599,LIGHTGOLDENRODYELLOW:4210742015,LIGHTGRAY:3553874943,LIGHTGREEN:2431553791,LIGHTGREY:3553874943,LIGHTPINK:4290167295,LIGHTSALMON:4288707327,LIGHTSEAGREEN:548580095,LIGHTSKYBLUE:2278488831,LIGHTSLATEGRAY:2005441023,LIGHTSLATEGREY:2005441023,LIGHTSTEELBLUE:2965692159,LIGHTYELLOW:4294959359,LIME:16711935,LIMEGREEN:852308735,LINEN:4210091775,MAGENTA:4278255615,MAROON:2147483903,MEDIUMAQUAMARINE:1724754687,MEDIUMBLUE:52735,MEDIUMORCHID:3126187007,MEDIUMPURPLE:2473647103,MEDIUMSEAGREEN:1018393087,MEDIUMSLATEBLUE:2070474495,MEDIUMSPRINGGREEN:16423679,MEDIUMTURQUOISE:1221709055,MEDIUMVIOLETRED:3340076543,MIDNIGHTBLUE:421097727,MINTCREAM:4127193855,MISTYROSE:4293190143,MOCCASIN:4293178879,NAVAJOWHITE:4292783615,NAVY:33023,OLDLACE:4260751103,OLIVE:2155872511,OLIVEDRAB:1804477439,ORANGE:4289003775,ORANGERED:4282712319,ORCHID:3664828159,PALEGOLDENROD:4008225535,PALEGREEN:2566625535,PALETURQUOISE:2951671551,PALEVIOLETRED:3681588223,PAPAYAWHIP:4293907967,PEACHPUFF:4292524543,PERU:3448061951,PINK:4290825215,PLUM:3718307327,POWDERBLUE:2967529215,PURPLE:2147516671,REBECCAPURPLE:1714657791,RED:4278190335,ROSYBROWN:3163525119,ROYALBLUE:1097458175,SADDLEBROWN:2336560127,SALMON:4202722047,SANDYBROWN:4104413439,SEAGREEN:780883967,SEASHELL:4294307583,SIENNA:2689740287,SILVER:3233857791,SKYBLUE:2278484991,SLATEBLUE:1784335871,SLATEGRAY:1887473919,SLATEGREY:1887473919,SNOW:4294638335,SPRINGGREEN:16744447,STEELBLUE:1182971135,TAN:3535047935,TEAL:8421631,THISTLE:3636451583,TOMATO:4284696575,TRANSPARENT:0,TURQUOISE:1088475391,VIOLET:4001558271,WHEAT:4125012991,WHITE:4294967295,WHITESMOKE:4126537215,YELLOW:4294902015,YELLOWGREEN:2597139199},es={name:"background-clip",initialValue:"border-box",prefix:!1,type:1,parse:function(A,e){return e.map(function(A){if(AM(A))switch(A.value){case"padding-box":return 1;case"content-box":return 2}return 0})}},eo={name:"background-color",initialValue:"transparent",prefix:!1,type:3,format:"color"},ei=function(A,e){var t=A4.parse(A,e[0]),r=e[1];return r&&AN(r)?{color:t,stop:r}:{color:t,stop:null}},eQ=function(A,e){var t=A[0],r=A[A.length-1];null===t.stop&&(t.stop=AX),null===r.stop&&(r.stop=AY);for(var B=[],n=0,s=0;s<A.length;s++){var o=A[s].stop;if(null!==o){var i=AZ(o,e);i>n?B.push(i):B.push(n),n=i}else B.push(null)}for(var Q=null,s=0;s<B.length;s++){var a=B[s];if(null===a)null===Q&&(Q=s);else if(null!==Q){for(var c=s-Q,g=(a-B[Q-1])/(c+1),w=1;w<=c;w++)B[Q+w-1]=g*w;Q=null}}return A.map(function(A,t){return{color:A.color,stop:Math.max(Math.min(1,B[t]/e),0)}})},ea=function(A,e,t){var r=AZ(A[0],e)-e/2;return(Math.atan2(t/2-AZ(A[1],t),r)+2*Math.PI)%(2*Math.PI)},ec=function(A,e,t){var r="number"==typeof A?A:ea(A,e,t),B=Math.abs(e*Math.sin(r))+Math.abs(t*Math.cos(r)),n=e/2,s=t/2,o=B/2,i=Math.sin(r-Math.PI/2)*o,Q=Math.cos(r-Math.PI/2)*o;return[B,n-Q,n+Q,s-i,s+i]},eg=function(A,e){return Math.sqrt(A*A+e*e)},ew=function(A,e,t,r,B){return[[0,0],[0,e],[A,0],[A,e]].reduce(function(A,e){var n,s=eg(t-e[0],r-e[1]);return(B?s<A.optimumDistance:s>A.optimumDistance)?{optimumCorner:e,optimumDistance:s}:A},{optimumDistance:B?1/0:-1/0,optimumCorner:null}).optimumCorner},el=function(A,e,t,r,B){var n=0,s=0;switch(A.size){case 0:0===A.shape?n=s=Math.min(Math.abs(e),Math.abs(e-r),Math.abs(t),Math.abs(t-B)):1===A.shape&&(n=Math.min(Math.abs(e),Math.abs(e-r)),s=Math.min(Math.abs(t),Math.abs(t-B)));break;case 2:if(0===A.shape)n=s=Math.min(eg(e,t),eg(e,t-B),eg(e-r,t),eg(e-r,t-B));else if(1===A.shape){var o=Math.min(Math.abs(t),Math.abs(t-B))/Math.min(Math.abs(e),Math.abs(e-r)),i=ew(r,B,e,t,!0),Q=i[0],a=i[1];n=eg(Q-e,(a-t)/o),s=o*n}break;case 1:0===A.shape?n=s=Math.max(Math.abs(e),Math.abs(e-r),Math.abs(t),Math.abs(t-B)):1===A.shape&&(n=Math.max(Math.abs(e),Math.abs(e-r)),s=Math.max(Math.abs(t),Math.abs(t-B)));break;case 3:if(0===A.shape)n=s=Math.max(eg(e,t),eg(e,t-B),eg(e-r,t),eg(e-r,t-B));else if(1===A.shape){var o=Math.max(Math.abs(t),Math.abs(t-B))/Math.max(Math.abs(e),Math.abs(e-r)),c=ew(r,B,e,t,!1),Q=c[0],a=c[1];n=eg(Q-e,(a-t)/o),s=o*n}}return Array.isArray(A.size)&&(n=AZ(A.size[0],r),s=2===A.size.length?AZ(A.size[1],B):n),[n,s]},eu=function(A,e){var t=A0(180),r=[];return AV(e).forEach(function(e,B){if(0===B){var n=e[0];if(20===n.type&&-1!==["top","left","right","bottom"].indexOf(n.value)){t=A$(e);return}if(Az(n)){t=(Aj.parse(A,n)+A0(270))%A0(360);return}}var s=ei(A,e);r.push(s)}),{angle:t,stops:r,type:1}},eU="closest-side",eC="farthest-side",eF="closest-corner",eh="farthest-corner",ed="circle",ef="ellipse",eH="cover",ep="contain",eE=function(A,e){var t=0,r=3,B=[],n=[];return AV(e).forEach(function(e,s){var o=!0;if(0===s?o=e.reduce(function(A,e){if(AM(e))switch(e.value){case"center":return n.push(AJ),!1;case"top":case"left":return n.push(AX),!1;case"right":case"bottom":return n.push(AY),!1}else if(AN(e)||AR(e))return n.push(e),!1;return A},o):1===s&&(o=e.reduce(function(A,e){if(AM(e))switch(e.value){case ed:return t=0,!1;case ef:return t=1,!1;case ep:case eU:return r=0,!1;case eC:return r=1,!1;case eF:return r=2,!1;case eH:case eh:return r=3,!1}else if(AR(e)||AN(e))return Array.isArray(r)||(r=[]),r.push(e),!1;return A},o)),o){var i=ei(A,e);B.push(i)}}),{size:r,shape:t,stops:B,position:n,type:2}},eI={name:"image",parse:function(A,e){if(22===e.type){var t={url:e.value,type:0};return A.cache.addImage(e.value),t}if(18===e.type){var r=ey[e.name];if(void 0===r)throw Error('Attempting to parse an unsupported image function "'+e.name+'"');return r(A,e.values)}throw Error("Unsupported image type "+e.type)}},ey={"linear-gradient":function(A,e){var t=A0(180),r=[];return AV(e).forEach(function(e,B){if(0===B){var n=e[0];if(20===n.type&&"to"===n.value){t=A$(e);return}if(Az(n)){t=Aj.parse(A,n);return}}var s=ei(A,e);r.push(s)}),{angle:t,stops:r,type:1}},"-moz-linear-gradient":eu,"-ms-linear-gradient":eu,"-o-linear-gradient":eu,"-webkit-linear-gradient":eu,"radial-gradient":function(A,e){var t=0,r=3,B=[],n=[];return AV(e).forEach(function(e,s){var o=!0;if(0===s){var i=!1;o=e.reduce(function(A,e){if(i){if(AM(e))switch(e.value){case"center":n.push(AJ);break;case"top":case"left":n.push(AX);break;case"right":case"bottom":n.push(AY)}else(AN(e)||AR(e))&&n.push(e)}else if(AM(e))switch(e.value){case ed:return t=0,!1;case ef:return t=1,!1;case"at":return i=!0,!1;case eU:return r=0,!1;case eH:case eC:return r=1,!1;case ep:case eF:return r=2,!1;case eh:return r=3,!1}else if(AR(e)||AN(e))return Array.isArray(r)||(r=[]),r.push(e),!1;return A},o)}if(o){var Q=ei(A,e);B.push(Q)}}),{size:r,shape:t,stops:B,position:n,type:2}},"-moz-radial-gradient":eE,"-ms-radial-gradient":eE,"-o-radial-gradient":eE,"-webkit-radial-gradient":eE,"-webkit-gradient":function(A,e){var t=A0(180),r=[],B=1;return AV(e).forEach(function(e,t){var n=e[0];if(0===t){if(AM(n)&&"linear"===n.value){B=1;return}if(AM(n)&&"radial"===n.value){B=2;return}}if(18===n.type){if("from"===n.name){var s=A4.parse(A,n.values[0]);r.push({stop:AX,color:s})}else if("to"===n.name){var s=A4.parse(A,n.values[0]);r.push({stop:AY,color:s})}else if("color-stop"===n.name){var o=n.values.filter(AO);if(2===o.length){var s=A4.parse(A,o[1]),i=o[0];Ax(i)&&r.push({stop:{type:16,number:100*i.number,flags:i.flags},color:s})}}}}),1===B?{angle:(t+A0(180))%A0(360),stops:r,type:B}:{size:3,shape:0,stops:r,position:[],type:B}}},eK={name:"background-image",initialValue:"none",type:1,prefix:!1,parse:function(A,e){if(0===e.length)return[];var t=e[0];return 20===t.type&&"none"===t.value?[]:e.filter(function(A){var e;return AO(A)&&!(20===A.type&&"none"===A.value)&&(18!==A.type||!!ey[A.name])}).map(function(e){return eI.parse(A,e)})}},em={name:"background-origin",initialValue:"border-box",prefix:!1,type:1,parse:function(A,e){return e.map(function(A){if(AM(A))switch(A.value){case"padding-box":return 1;case"content-box":return 2}return 0})}},eL={name:"background-position",initialValue:"0% 0%",type:1,prefix:!1,parse:function(A,e){return AV(e).map(function(A){return A.filter(AN)}).map(AP)}},ev={name:"background-repeat",initialValue:"repeat",prefix:!1,type:1,parse:function(A,e){return AV(e).map(function(A){return A.filter(AM).map(function(A){return A.value}).join(" ")}).map(eb)}},eb=function(A){switch(A){case"no-repeat":return 1;case"repeat-x":case"repeat no-repeat":return 2;case"repeat-y":case"no-repeat repeat":return 3;default:return 0}};(A7=A||(A={})).AUTO="auto",A7.CONTAIN="contain",A7.COVER="cover";var eD,ex={name:"background-size",initialValue:"0",prefix:!1,type:1,parse:function(A,e){return AV(e).map(function(A){return A.filter(eM)})}},eM=function(A){return AM(A)||AN(A)},eS=function(A){return{name:"border-"+A+"-color",initialValue:"transparent",prefix:!1,type:3,format:"color"}},eT=eS("top"),eG=eS("right"),eO=eS("bottom"),eV=eS("left"),ek=function(A){return{name:"border-radius-"+A,initialValue:"0 0",prefix:!1,type:1,parse:function(A,e){return AP(e.filter(AN))}}},eR=ek("top-left"),eN=ek("top-right"),eP=ek("bottom-right"),eX=ek("bottom-left"),eJ=function(A){return{name:"border-"+A+"-style",initialValue:"solid",prefix:!1,type:2,parse:function(A,e){switch(e){case"none":return 0;case"dashed":return 2;case"dotted":return 3;case"double":return 4}return 1}}},eY=eJ("top"),eW=eJ("right"),eZ=eJ("bottom"),e_=eJ("left"),eq=function(A){return{name:"border-"+A+"-width",initialValue:"0",type:0,prefix:!1,parse:function(A,e){return AD(e)?e.number:0}}},ej=eq("top"),ez=eq("right"),e$=eq("bottom"),e0=eq("left"),e4={name:"color",initialValue:"transparent",prefix:!1,type:3,format:"color"},e1={name:"direction",initialValue:"ltr",prefix:!1,type:2,parse:function(A,e){return"rtl"===e?1:0}},e2={name:"display",initialValue:"inline-block",prefix:!1,type:1,parse:function(A,e){return e.filter(AM).reduce(function(A,e){return A|e3(e.value)},0)}},e3=function(A){switch(A){case"block":case"-webkit-box":return 2;case"inline":return 4;case"run-in":return 8;case"flow":return 16;case"flow-root":return 32;case"table":return 64;case"flex":case"-webkit-flex":return 128;case"grid":case"-ms-grid":return 256;case"ruby":return 512;case"subgrid":return 1024;case"list-item":return 2048;case"table-row-group":return 4096;case"table-header-group":return 8192;case"table-footer-group":return 16384;case"table-row":return 32768;case"table-cell":return 65536;case"table-column-group":return 131072;case"table-column":return 262144;case"table-caption":return 524288;case"ruby-base":return 1048576;case"ruby-text":return 2097152;case"ruby-base-container":return 4194304;case"ruby-text-container":return 8388608;case"contents":return 16777216;case"inline-block":return 33554432;case"inline-list-item":return 67108864;case"inline-table":return 134217728;case"inline-flex":return 268435456;case"inline-grid":return 536870912}return 0},e5={name:"float",initialValue:"none",prefix:!1,type:2,parse:function(A,e){switch(e){case"left":return 1;case"right":return 2;case"inline-start":return 3;case"inline-end":return 4}return 0}},e6={name:"letter-spacing",initialValue:"0",prefix:!1,type:0,parse:function(A,e){return 20===e.type&&"normal"===e.value?0:17===e.type||15===e.type?e.number:0}};(eD=e||(e={})).NORMAL="normal",eD.STRICT="strict";var e8,e7={name:"line-break",initialValue:"normal",prefix:!1,type:2,parse:function(A,t){return"strict"===t?e.STRICT:(0,e.NORMAL)}},e9={name:"line-height",initialValue:"normal",prefix:!1,type:4},tA=function(A,e){return AM(A)&&"normal"===A.value?1.2*e:17===A.type?e*A.number:AN(A)?AZ(A,e):e},te={name:"list-style-image",initialValue:"none",type:0,prefix:!1,parse:function(A,e){return 20===e.type&&"none"===e.value?null:eI.parse(A,e)}},tt={name:"list-style-position",initialValue:"outside",prefix:!1,type:2,parse:function(A,e){return"inside"===e?0:1}},tr={name:"list-style-type",initialValue:"none",prefix:!1,type:2,parse:function(A,e){switch(e){case"disc":return 0;case"circle":return 1;case"square":return 2;case"decimal":return 3;case"cjk-decimal":return 4;case"decimal-leading-zero":return 5;case"lower-roman":return 6;case"upper-roman":return 7;case"lower-greek":return 8;case"lower-alpha":return 9;case"upper-alpha":return 10;case"arabic-indic":return 11;case"armenian":return 12;case"bengali":return 13;case"cambodian":return 14;case"cjk-earthly-branch":return 15;case"cjk-heavenly-stem":return 16;case"cjk-ideographic":return 17;case"devanagari":return 18;case"ethiopic-numeric":return 19;case"georgian":return 20;case"gujarati":return 21;case"gurmukhi":case"hebrew":return 22;case"hiragana":return 23;case"hiragana-iroha":return 24;case"japanese-formal":return 25;case"japanese-informal":return 26;case"kannada":return 27;case"katakana":return 28;case"katakana-iroha":return 29;case"khmer":return 30;case"korean-hangul-formal":return 31;case"korean-hanja-formal":return 32;case"korean-hanja-informal":return 33;case"lao":return 34;case"lower-armenian":return 35;case"malayalam":return 36;case"mongolian":return 37;case"myanmar":return 38;case"oriya":return 39;case"persian":return 40;case"simp-chinese-formal":return 41;case"simp-chinese-informal":return 42;case"tamil":return 43;case"telugu":return 44;case"thai":return 45;case"tibetan":return 46;case"trad-chinese-formal":return 47;case"trad-chinese-informal":return 48;case"upper-armenian":return 49;case"disclosure-open":return 50;case"disclosure-closed":return 51;default:return -1}}},tB=function(A){return{name:"margin-"+A,initialValue:"0",prefix:!1,type:4}},tn=tB("top"),ts=tB("right"),to=tB("bottom"),ti=tB("left"),tQ={name:"overflow",initialValue:"visible",prefix:!1,type:1,parse:function(A,e){return e.filter(AM).map(function(A){switch(A.value){case"hidden":return 1;case"scroll":return 2;case"clip":return 3;case"auto":return 4;default:return 0}})}},ta={name:"overflow-wrap",initialValue:"normal",prefix:!1,type:2,parse:function(A,e){return"break-word"===e?"break-word":"normal"}},tc=function(A){return{name:"padding-"+A,initialValue:"0",prefix:!1,type:3,format:"length-percentage"}},tg=tc("top"),tw=tc("right"),tl=tc("bottom"),tu=tc("left"),tU={name:"text-align",initialValue:"left",prefix:!1,type:2,parse:function(A,e){switch(e){case"right":return 2;case"center":case"justify":return 1;default:return 0}}},tC={name:"position",initialValue:"static",prefix:!1,type:2,parse:function(A,e){switch(e){case"relative":return 1;case"absolute":return 2;case"fixed":return 3;case"sticky":return 4}return 0}},tF={name:"text-shadow",initialValue:"none",type:1,prefix:!1,parse:function(A,e){return 1===e.length&&AT(e[0],"none")?[]:AV(e).map(function(e){for(var t={color:en.TRANSPARENT,offsetX:AX,offsetY:AX,blur:AX},r=0,B=0;B<e.length;B++){var n=e[B];AR(n)?(0===r?t.offsetX=n:1===r?t.offsetY=n:t.blur=n,r++):t.color=A4.parse(A,n)}return t})}},th={name:"text-transform",initialValue:"none",prefix:!1,type:2,parse:function(A,e){switch(e){case"uppercase":return 2;case"lowercase":return 1;case"capitalize":return 3}return 0}},td={name:"transform",initialValue:"none",prefix:!0,type:0,parse:function(A,e){if(20===e.type&&"none"===e.value)return null;if(18===e.type){var t=tf[e.name];if(void 0===t)throw Error('Attempting to parse an unsupported transform function "'+e.name+'"');return t(e.values)}return null}},tf={matrix:function(A){var e=A.filter(function(A){return 17===A.type}).map(function(A){return A.number});return 6===e.length?e:null},matrix3d:function(A){var e=A.filter(function(A){return 17===A.type}).map(function(A){return A.number}),t=e[0],r=e[1];e[2],e[3];var B=e[4],n=e[5];e[6],e[7],e[8],e[9],e[10],e[11];var s=e[12],o=e[13];return e[14],e[15],16===e.length?[t,r,B,n,s,o]:null}},tH={type:16,number:50,flags:4},tp=[tH,tH],tE={name:"transform-origin",initialValue:"50% 50%",prefix:!0,type:1,parse:function(A,e){var t=e.filter(AN);return 2!==t.length?tp:[t[0],t[1]]}},tI={name:"visible",initialValue:"none",prefix:!1,type:2,parse:function(A,e){switch(e){case"hidden":return 1;case"collapse":return 2;default:return 0}}};(e8=t||(t={})).NORMAL="normal",e8.BREAK_ALL="break-all",e8.KEEP_ALL="keep-all";for(var ty={name:"word-break",initialValue:"normal",prefix:!1,type:2,parse:function(A,e){switch(e){case"break-all":return t.BREAK_ALL;case"keep-all":return t.KEEP_ALL;default:return t.NORMAL}}},tK={name:"z-index",initialValue:"auto",prefix:!1,type:0,parse:function(A,e){if(20===e.type)return{auto:!0,order:0};if(Ax(e))return{auto:!1,order:e.number};throw Error("Invalid z-index number parsed")}},tm={name:"time",parse:function(A,e){if(15===e.type)switch(e.unit.toLowerCase()){case"s":return 1e3*e.number;case"ms":return e.number}throw Error("Unsupported time type")}},tL={name:"opacity",initialValue:"1",type:0,prefix:!1,parse:function(A,e){return Ax(e)?e.number:1}},tv={name:"text-decoration-color",initialValue:"transparent",prefix:!1,type:3,format:"color"},tb={name:"text-decoration-line",initialValue:"none",prefix:!1,type:1,parse:function(A,e){return e.filter(AM).map(function(A){switch(A.value){case"underline":return 1;case"overline":return 2;case"line-through":return 3;case"none":return 4}return 0}).filter(function(A){return 0!==A})}},tD={name:"font-family",initialValue:"",prefix:!1,type:1,parse:function(A,e){var t=[],r=[];return e.forEach(function(A){switch(A.type){case 20:case 0:t.push(A.value);break;case 17:t.push(A.number.toString());break;case 4:r.push(t.join(" ")),t.length=0}}),t.length&&r.push(t.join(" ")),r.map(function(A){return -1===A.indexOf(" ")?A:"'"+A+"'"})}},tx={name:"font-size",initialValue:"0",prefix:!1,type:3,format:"length"},tM={name:"font-weight",initialValue:"normal",type:0,prefix:!1,parse:function(A,e){return Ax(e)?e.number:AM(e)&&"bold"===e.value?700:400}},tS={name:"font-variant",initialValue:"none",type:1,prefix:!1,parse:function(A,e){return e.filter(AM).map(function(A){return A.value})}},tT={name:"font-style",initialValue:"normal",prefix:!1,type:2,parse:function(A,e){switch(e){case"oblique":return"oblique";case"italic":return"italic";default:return"normal"}}},tG=function(A,e){return(A&e)!=0},tO={name:"content",initialValue:"none",type:1,prefix:!1,parse:function(A,e){if(0===e.length)return[];var t=e[0];return 20===t.type&&"none"===t.value?[]:e}},tV={name:"counter-increment",initialValue:"none",prefix:!0,type:1,parse:function(A,e){if(0===e.length)return null;var t=e[0];if(20===t.type&&"none"===t.value)return null;for(var r=[],B=e.filter(AG),n=0;n<B.length;n++){var s=B[n],o=B[n+1];if(20===s.type){var i=o&&Ax(o)?o.number:1;r.push({counter:s.value,increment:i})}}return r}},tk={name:"counter-reset",initialValue:"none",prefix:!0,type:1,parse:function(A,e){if(0===e.length)return[];for(var t=[],r=e.filter(AG),B=0;B<r.length;B++){var n=r[B],s=r[B+1];if(AM(n)&&"none"!==n.value){var o=s&&Ax(s)?s.number:0;t.push({counter:n.value,reset:o})}}return t}},tR={name:"duration",initialValue:"0s",prefix:!1,type:1,parse:function(A,e){return e.filter(AD).map(function(e){return tm.parse(A,e)})}},tN={name:"quotes",initialValue:"none",prefix:!0,type:1,parse:function(A,e){if(0===e.length)return null;var t=e[0];if(20===t.type&&"none"===t.value)return null;var r=[],B=e.filter(AS);if(B.length%2!=0)return null;for(var n=0;n<B.length;n+=2){var s=B[n].value,o=B[n+1].value;r.push({open:s,close:o})}return r}},tP=function(A,e,t){if(!A)return"";var r=A[Math.min(e,A.length-1)];return r?t?r.open:r.close:""},tX={name:"box-shadow",initialValue:"none",type:1,prefix:!1,parse:function(A,e){return 1===e.length&&AT(e[0],"none")?[]:AV(e).map(function(e){for(var t={color:255,offsetX:AX,offsetY:AX,blur:AX,spread:AX,inset:!1},r=0,B=0;B<e.length;B++){var n=e[B];AT(n,"inset")?t.inset=!0:AR(n)?(0===r?t.offsetX=n:1===r?t.offsetY=n:2===r?t.blur=n:t.spread=n,r++):t.color=A4.parse(A,n)}return t})}},tJ={name:"paint-order",initialValue:"normal",prefix:!1,type:1,parse:function(A,e){var t=[];return e.filter(AM).forEach(function(A){switch(A.value){case"stroke":t.push(1);break;case"fill":t.push(0);break;case"markers":t.push(2)}}),[0,1,2].forEach(function(A){-1===t.indexOf(A)&&t.push(A)}),t}},tY={name:"-webkit-text-stroke-color",initialValue:"currentcolor",prefix:!1,type:3,format:"color"},tW={name:"-webkit-text-stroke-width",initialValue:"0",type:0,prefix:!1,parse:function(A,e){return AD(e)?e.number:0}},tZ=function(){function A(A,e){this.animationDuration=tj(A,tR,e.animationDuration),this.backgroundClip=tj(A,es,e.backgroundClip),this.backgroundColor=tj(A,eo,e.backgroundColor),this.backgroundImage=tj(A,eK,e.backgroundImage),this.backgroundOrigin=tj(A,em,e.backgroundOrigin),this.backgroundPosition=tj(A,eL,e.backgroundPosition),this.backgroundRepeat=tj(A,ev,e.backgroundRepeat),this.backgroundSize=tj(A,ex,e.backgroundSize),this.borderTopColor=tj(A,eT,e.borderTopColor),this.borderRightColor=tj(A,eG,e.borderRightColor),this.borderBottomColor=tj(A,eO,e.borderBottomColor),this.borderLeftColor=tj(A,eV,e.borderLeftColor),this.borderTopLeftRadius=tj(A,eR,e.borderTopLeftRadius),this.borderTopRightRadius=tj(A,eN,e.borderTopRightRadius),this.borderBottomRightRadius=tj(A,eP,e.borderBottomRightRadius),this.borderBottomLeftRadius=tj(A,eX,e.borderBottomLeftRadius),this.borderTopStyle=tj(A,eY,e.borderTopStyle),this.borderRightStyle=tj(A,eW,e.borderRightStyle),this.borderBottomStyle=tj(A,eZ,e.borderBottomStyle),this.borderLeftStyle=tj(A,e_,e.borderLeftStyle),this.borderTopWidth=tj(A,ej,e.borderTopWidth),this.borderRightWidth=tj(A,ez,e.borderRightWidth),this.borderBottomWidth=tj(A,e$,e.borderBottomWidth),this.borderLeftWidth=tj(A,e0,e.borderLeftWidth),this.boxShadow=tj(A,tX,e.boxShadow),this.color=tj(A,e4,e.color),this.direction=tj(A,e1,e.direction),this.display=tj(A,e2,e.display),this.float=tj(A,e5,e.cssFloat),this.fontFamily=tj(A,tD,e.fontFamily),this.fontSize=tj(A,tx,e.fontSize),this.fontStyle=tj(A,tT,e.fontStyle),this.fontVariant=tj(A,tS,e.fontVariant),this.fontWeight=tj(A,tM,e.fontWeight),this.letterSpacing=tj(A,e6,e.letterSpacing),this.lineBreak=tj(A,e7,e.lineBreak),this.lineHeight=tj(A,e9,e.lineHeight),this.listStyleImage=tj(A,te,e.listStyleImage),this.listStylePosition=tj(A,tt,e.listStylePosition),this.listStyleType=tj(A,tr,e.listStyleType),this.marginTop=tj(A,tn,e.marginTop),this.marginRight=tj(A,ts,e.marginRight),this.marginBottom=tj(A,to,e.marginBottom),this.marginLeft=tj(A,ti,e.marginLeft),this.opacity=tj(A,tL,e.opacity);var t,r,B=tj(A,tQ,e.overflow);this.overflowX=B[0],this.overflowY=B[B.length>1?1:0],this.overflowWrap=tj(A,ta,e.overflowWrap),this.paddingTop=tj(A,tg,e.paddingTop),this.paddingRight=tj(A,tw,e.paddingRight),this.paddingBottom=tj(A,tl,e.paddingBottom),this.paddingLeft=tj(A,tu,e.paddingLeft),this.paintOrder=tj(A,tJ,e.paintOrder),this.position=tj(A,tC,e.position),this.textAlign=tj(A,tU,e.textAlign),this.textDecorationColor=tj(A,tv,null!==(t=e.textDecorationColor)&&void 0!==t?t:e.color),this.textDecorationLine=tj(A,tb,null!==(r=e.textDecorationLine)&&void 0!==r?r:e.textDecoration),this.textShadow=tj(A,tF,e.textShadow),this.textTransform=tj(A,th,e.textTransform),this.transform=tj(A,td,e.transform),this.transformOrigin=tj(A,tE,e.transformOrigin),this.visibility=tj(A,tI,e.visibility),this.webkitTextStrokeColor=tj(A,tY,e.webkitTextStrokeColor),this.webkitTextStrokeWidth=tj(A,tW,e.webkitTextStrokeWidth),this.wordBreak=tj(A,ty,e.wordBreak),this.zIndex=tj(A,tK,e.zIndex)}return A.prototype.isVisible=function(){return this.display>0&&this.opacity>0&&0===this.visibility},A.prototype.isTransparent=function(){return A1(this.backgroundColor)},A.prototype.isTransformed=function(){return null!==this.transform},A.prototype.isPositioned=function(){return 0!==this.position},A.prototype.isPositionedWithZIndex=function(){return this.isPositioned()&&!this.zIndex.auto},A.prototype.isFloating=function(){return 0!==this.float},A.prototype.isInlineLevel=function(){return tG(this.display,4)||tG(this.display,33554432)||tG(this.display,268435456)||tG(this.display,536870912)||tG(this.display,67108864)||tG(this.display,134217728)},A}(),t_=function(A,e){this.content=tj(A,tO,e.content),this.quotes=tj(A,tN,e.quotes)},tq=function(A,e){this.counterIncrement=tj(A,tV,e.counterIncrement),this.counterReset=tj(A,tk,e.counterReset)},tj=function(A,e,t){var r=new Av,B=null!=t?t.toString():e.initialValue;r.write(B);var n=new Ab(r.read());switch(e.type){case 2:var s=n.parseComponentValue();return e.parse(A,AM(s)?s.value:e.initialValue);case 0:return e.parse(A,n.parseComponentValue());case 1:return e.parse(A,n.parseComponentValues());case 4:return n.parseComponentValue();case 3:switch(e.format){case"angle":return Aj.parse(A,n.parseComponentValue());case"color":return A4.parse(A,n.parseComponentValue());case"image":return eI.parse(A,n.parseComponentValue());case"length":var o=n.parseComponentValue();return AR(o)?o:AX;case"length-percentage":var i=n.parseComponentValue();return AN(i)?i:AX;case"time":return tm.parse(A,n.parseComponentValue())}}},tz=function(A){var e=A.getAttribute("data-html2canvas-debug");switch(e){case"all":return 1;case"clone":return 2;case"parse":return 3;case"render":return 4;default:return 0}},t$=function(A,e){var t=tz(A);return 1===t||e===t},t0=function(A,e){this.context=A,this.textNodes=[],this.elements=[],this.flags=0,t$(e,3),this.styles=new tZ(A,window.getComputedStyle(e,null)),Bi(e)&&(this.styles.animationDuration.some(function(A){return A>0})&&(e.style.animationDuration="0s"),null!==this.styles.transform&&(e.style.transform="none")),this.bounds=g(this.context,e),t$(e,4)&&(this.flags|=16)},t4="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t1="undefined"==typeof Uint8Array?[]:new Uint8Array(256),t2=0;t2<t4.length;t2++)t1[t4.charCodeAt(t2)]=t2;for(var t3=2112,t5=function(A,e,t){return A.slice?A.slice(e,t):new Uint16Array(Array.prototype.slice.call(A,e,t))},t6=function(){function A(A,e,t,r,B,n){this.initialValue=A,this.errorValue=e,this.highStart=t,this.highValueIndex=r,this.index=B,this.data=n}return A.prototype.get=function(A){var e;if(A>=0){if(A<55296||A>56319&&A<=65535)return e=((e=this.index[A>>5])<<2)+(31&A),this.data[e];if(A<=65535)return e=((e=this.index[2048+(A-55296>>5)])<<2)+(31&A),this.data[e];if(A<this.highStart)return e=t3-32+(A>>11),e=this.index[e],e+=A>>5&63,e=((e=this.index[e])<<2)+(31&A),this.data[e];if(A<=1114111)return this.data[this.highValueIndex]}return this.errorValue},A}(),t8="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t7="undefined"==typeof Uint8Array?[]:new Uint8Array(256),t9=0;t9<t8.length;t9++)t7[t8.charCodeAt(t9)]=t9;var rA,re,rt,rr,rB,rn,rs,ro,ri,rQ,ra=function(A){for(var e=[],t=0,r=A.length;t<r;){var B=A.charCodeAt(t++);if(B>=55296&&B<=56319&&t<r){var n=A.charCodeAt(t++);(64512&n)==56320?e.push(((1023&B)<<10)+(1023&n)+65536):(e.push(B),t--)}else e.push(B)}return e},rc=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];if(String.fromCodePoint)return String.fromCodePoint.apply(String,A);var t=A.length;if(!t)return"";for(var r=[],B=-1,n="";++B<t;){var s=A[B];s<=65535?r.push(s):(s-=65536,r.push((s>>10)+55296,s%1024+56320)),(B+1===t||r.length>16384)&&(n+=String.fromCharCode.apply(String,r),r.length=0)}return n},rg=(rt=Array.isArray(re=function(A){var e,t,r,B,n,s=.75*A.length,o=A.length,i=0;"="===A[A.length-1]&&(s--,"="===A[A.length-2]&&s--);var Q="undefined"!=typeof ArrayBuffer&&"undefined"!=typeof Uint8Array&&void 0!==Uint8Array.prototype.slice?new ArrayBuffer(s):Array(s),a=Array.isArray(Q)?Q:new Uint8Array(Q);for(e=0;e<o;e+=4)t=t1[A.charCodeAt(e)],r=t1[A.charCodeAt(e+1)],B=t1[A.charCodeAt(e+2)],n=t1[A.charCodeAt(e+3)],a[i++]=t<<2|r>>4,a[i++]=(15&r)<<4|B>>2,a[i++]=(3&B)<<6|63&n;return Q}(" "))?function(A){for(var e=A.length,t=[],r=0;r<e;r+=4)t.push(A[r+3]<<24|A[r+2]<<16|A[r+1]<<8|A[r]);return t}(re):new Uint32Array(re),rr=Array.isArray(re)?function(A){for(var e=A.length,t=[],r=0;r<e;r+=2)t.push(A[r+1]<<8|A[r]);return t}(re):new Uint16Array(re),rB=t5(rr,12,rt[4]/2),ri=2===rt[5]?t5(rr,(24+rt[4])/2):(rs=Math.ceil((24+rt[4])/4),rt.slice?rt.slice(rs,ro):new Uint32Array(Array.prototype.slice.call(rt,rs,ro))),new t6(rt[0],rt[1],rt[2],rt[3],rB,ri)),rw=function(A){return rg.get(A)},rl=function(A,e,t){var r=t-2,B=e[r],n=e[t-1],s=e[t];if(2===n&&3===s)return"\xd7";if(2===n||3===n||4===n||2===s||3===s||4===s)return"\xf7";if(8===n&&-1!==[8,9,11,12].indexOf(s)||(11===n||9===n)&&(9===s||10===s)||(12===n||10===n)&&10===s||13===s||5===s||7===s||1===n)return"\xd7";if(13===n&&14===s){for(;5===B;)B=e[--r];if(14===B)return"\xd7"}if(15===n&&15===s){for(var o=0;15===B;)o++,B=e[--r];if(o%2==0)return"\xd7"}return"\xf7"},ru=function(A){var e=ra(A),t=e.length,r=0,B=0,n=e.map(rw);return{next:function(){if(r>=t)return{done:!0,value:null};for(var A="\xd7";r<t&&"\xd7"===(A=rl(e,n,++r)););if("\xd7"!==A||r===t){var s=rc.apply(null,e.slice(B,r));return B=r,{value:s,done:!1}}return{done:!0,value:null}}}},rU=function(A){for(var e,t=ru(A),r=[];!(e=t.next()).done;)e.value&&r.push(e.value.slice());return r},rC=function(A){return 0===A[0]&&255===A[1]&&0===A[2]&&255===A[3]},rF=function(A,e,t,r,B){var n="http://www.w3.org/2000/svg",s=document.createElementNS(n,"svg"),o=document.createElementNS(n,"foreignObject");return s.setAttributeNS(null,"width",A.toString()),s.setAttributeNS(null,"height",e.toString()),o.setAttributeNS(null,"width","100%"),o.setAttributeNS(null,"height","100%"),o.setAttributeNS(null,"x",t.toString()),o.setAttributeNS(null,"y",r.toString()),o.setAttributeNS(null,"externalResourcesRequired","true"),s.appendChild(o),o.appendChild(B),s},rh=function(A){return new Promise(function(e,t){var r=new Image;r.onload=function(){return e(r)},r.onerror=t,r.src="data:image/svg+xml;charset=utf-8,"+encodeURIComponent(new XMLSerializer().serializeToString(A))})},rd={get SUPPORT_RANGE_BOUNDS(){var rf=function(A){if(A.createRange){var e=A.createRange();if(e.getBoundingClientRect){var t=A.createElement("boundtest");t.style.height="123px",t.style.display="block",A.body.appendChild(t),e.selectNode(t);var r=Math.round(e.getBoundingClientRect().height);if(A.body.removeChild(t),123===r)return!0}}return!1}(document);return Object.defineProperty(rd,"SUPPORT_RANGE_BOUNDS",{value:rf}),rf},get SUPPORT_WORD_BREAKING(){var rH,rp,rE,rI,ry,rK,rm,rL,rv=rd.SUPPORT_RANGE_BOUNDS&&((rp=(rH=document).createElement("boundtest")).style.width="50px",rp.style.display="block",rp.style.fontSize="12px",rp.style.letterSpacing="0px",rp.style.wordSpacing="0px",rH.body.appendChild(rp),rE=rH.createRange(),rp.innerHTML="function"==typeof"".repeat?"&#128104;".repeat(10):"",ry=l((rI=rp.firstChild).data).map(function(A){return u(A)}),rK=0,rm={},rL=ry.every(function(A,e){rE.setStart(rI,rK),rE.setEnd(rI,rK+A.length);var t=rE.getBoundingClientRect();rK+=A.length;var r=t.x>rm.x||t.y>rm.y;return rm=t,0===e||r}),rH.body.removeChild(rp),rL);return Object.defineProperty(rd,"SUPPORT_WORD_BREAKING",{value:rv}),rv},get SUPPORT_SVG_DRAWING(){var rb=function(A){var e=new Image,t=A.createElement("canvas"),r=t.getContext("2d");if(!r)return!1;e.src="data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg'></svg>";try{r.drawImage(e,0,0),t.toDataURL()}catch(B){return!1}return!0}(document);return Object.defineProperty(rd,"SUPPORT_SVG_DRAWING",{value:rb}),rb},get SUPPORT_FOREIGNOBJECT_DRAWING(){var rD="function"==typeof Array.from&&"function"==typeof window.fetch?function(A){var e=A.createElement("canvas");e.width=100,e.height=100;var t=e.getContext("2d");if(!t)return Promise.reject(!1);t.fillStyle="rgb(0, 255, 0)",t.fillRect(0,0,100,100);var r=new Image,B=e.toDataURL();r.src=B;var n=rF(100,100,0,0,r);return t.fillStyle="red",t.fillRect(0,0,100,100),rh(n).then(function(e){t.drawImage(e,0,0);var r=t.getImageData(0,0,100,100).data;t.fillStyle="red",t.fillRect(0,0,100,100);var n=A.createElement("div");return n.style.backgroundImage="url("+B+")",n.style.height="100px",rC(r)?rh(rF(100,100,0,0,n)):Promise.reject(!1)}).then(function(A){return t.drawImage(A,0,0),rC(t.getImageData(0,0,100,100).data)}).catch(function(){return!1})}(document):Promise.resolve(!1);return Object.defineProperty(rd,"SUPPORT_FOREIGNOBJECT_DRAWING",{value:rD}),rD},get SUPPORT_CORS_IMAGES(){var rx=void 0!==new Image().crossOrigin;return Object.defineProperty(rd,"SUPPORT_CORS_IMAGES",{value:rx}),rx},get SUPPORT_RESPONSE_TYPE(){var rM="string"==typeof new XMLHttpRequest().responseType;return Object.defineProperty(rd,"SUPPORT_RESPONSE_TYPE",{value:rM}),rM},get SUPPORT_CORS_XHR(){var rS="withCredentials"in new XMLHttpRequest;return Object.defineProperty(rd,"SUPPORT_CORS_XHR",{value:rS}),rS},get SUPPORT_NATIVE_TEXT_SEGMENTATION(){var rT=!!("undefined"!=typeof Intl&&Intl.Segmenter);return Object.defineProperty(rd,"SUPPORT_NATIVE_TEXT_SEGMENTATION",{value:rT}),rT}},rG=function(A,e){this.text=A,this.bounds=e},rO=function(A,e,t,r){var B=rN(e,t),n=[],s=0;return B.forEach(function(e){if(t.textDecorationLine.length||e.trim().length>0){if(rd.SUPPORT_RANGE_BOUNDS){var B=rk(r,s,e.length).getClientRects();if(B.length>1){var o=rR(e),i=0;o.forEach(function(e){n.push(new rG(e,c.fromDOMRectList(A,rk(r,i+s,e.length).getClientRects()))),i+=e.length})}else n.push(new rG(e,c.fromDOMRectList(A,B)))}else{var Q=r.splitText(e.length);n.push(new rG(e,rV(A,r))),r=Q}}else rd.SUPPORT_RANGE_BOUNDS||(r=r.splitText(e.length));s+=e.length}),n},rV=function(A,e){var t=e.ownerDocument;if(t){var r=t.createElement("html2canvaswrapper");r.appendChild(e.cloneNode(!0));var B=e.parentNode;if(B){B.replaceChild(r,e);var n=g(A,r);return r.firstChild&&B.replaceChild(r.firstChild,r),n}}return c.EMPTY},rk=function(A,e,t){var r=A.ownerDocument;if(!r)throw Error("Node has no owner document");var B=r.createRange();return B.setStart(A,e),B.setEnd(A,e+t),B},rR=function(A){return rd.SUPPORT_NATIVE_TEXT_SEGMENTATION?Array.from(new Intl.Segmenter(void 0,{granularity:"grapheme"}).segment(A)).map(function(A){return A.segment}):rU(A)},rN=function(A,e){var t,r;return 0!==e.letterSpacing?rR(A):(t=A,r=e,rd.SUPPORT_NATIVE_TEXT_SEGMENTATION?Array.from(new Intl.Segmenter(void 0,{granularity:"word"}).segment(t)).map(function(A){return A.segment}):rX(t,r))},rP=[32,160,4961,65792,65793,4153,4241],rX=function(A,e){for(var t,r=z(A,{lineBreak:e.lineBreak,wordBreak:"break-word"===e.overflowWrap?"break-word":e.wordBreak}),B=[];!(t=r.next()).done;)!function(){if(t.value){var A=l(t.value.slice()),e="";A.forEach(function(A){-1===rP.indexOf(A)?e+=u(A):(e.length&&B.push(e),B.push(u(A)),e="")}),e.length&&B.push(e)}}();return B},rJ=function(A,e,t){this.text=rY(e.data,t.textTransform),this.textBounds=rO(A,this.text,t,e)},rY=function(A,e){switch(e){case 1:return A.toLowerCase();case 3:return A.replace(rW,rZ);case 2:return A.toUpperCase();default:return A}},rW=/(^|\s|:|-|\(|\))([a-z])/g,rZ=function(A,e,t){return A.length>0?e+t.toUpperCase():A},r_=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.src=t.currentSrc||t.src,r.intrinsicWidth=t.naturalWidth,r.intrinsicHeight=t.naturalHeight,r.context.cache.addImage(r.src),r}return s(e,A),e}(t0),rq=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.canvas=t,r.intrinsicWidth=t.width,r.intrinsicHeight=t.height,r}return s(e,A),e}(t0),rj=function(A){function e(e,t){var r=A.call(this,e,t)||this,B=new XMLSerializer,n=g(e,t);return t.setAttribute("width",n.width+"px"),t.setAttribute("height",n.height+"px"),r.svg="data:image/svg+xml,"+encodeURIComponent(B.serializeToString(t)),r.intrinsicWidth=t.width.baseVal.value,r.intrinsicHeight=t.height.baseVal.value,r.context.cache.addImage(r.svg),r}return s(e,A),e}(t0),rz=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.value=t.value,r}return s(e,A),e}(t0),r$=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.start=t.start,r.reversed="boolean"==typeof t.reversed&&!0===t.reversed,r}return s(e,A),e}(t0),r0=[{type:15,flags:0,unit:"px",number:3}],r4=[{type:16,flags:0,number:50}],r1=function(A){var e=A.type===r5?Array(A.value.length+1).join("•"):A.value;return 0===e.length?A.placeholder||"":e},r2="checkbox",r3="radio",r5="password",r6=function(A){function e(e,t){var r,B=A.call(this,e,t)||this;switch(B.type=t.type.toLowerCase(),B.checked=t.checked,B.value=r1(t),(B.type===r2||B.type===r3)&&(B.styles.backgroundColor=3739148031,B.styles.borderTopColor=B.styles.borderRightColor=B.styles.borderBottomColor=B.styles.borderLeftColor=2779096575,B.styles.borderTopWidth=B.styles.borderRightWidth=B.styles.borderBottomWidth=B.styles.borderLeftWidth=1,B.styles.borderTopStyle=B.styles.borderRightStyle=B.styles.borderBottomStyle=B.styles.borderLeftStyle=1,B.styles.backgroundClip=[0],B.styles.backgroundOrigin=[0],B.bounds=(r=B.bounds).width>r.height?new c(r.left+(r.width-r.height)/2,r.top,r.height,r.height):r.width<r.height?new c(r.left,r.top+(r.height-r.width)/2,r.width,r.width):r),B.type){case r2:B.styles.borderTopRightRadius=B.styles.borderTopLeftRadius=B.styles.borderBottomRightRadius=B.styles.borderBottomLeftRadius=r0;break;case r3:B.styles.borderTopRightRadius=B.styles.borderTopLeftRadius=B.styles.borderBottomRightRadius=B.styles.borderBottomLeftRadius=r4}return B}return s(e,A),e}(t0),r8=function(A){function e(e,t){var r=A.call(this,e,t)||this,B=t.options[t.selectedIndex||0];return r.value=B&&B.text||"",r}return s(e,A),e}(t0),r7=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.value=t.value,r}return s(e,A),e}(t0),r9=function(A){function e(e,t){var r=A.call(this,e,t)||this;r.src=t.src,r.width=parseInt(t.width,10)||0,r.height=parseInt(t.height,10)||0,r.backgroundColor=r.styles.backgroundColor;try{if(t.contentWindow&&t.contentWindow.document&&t.contentWindow.document.documentElement){r.tree=Br(e,t.contentWindow.document.documentElement);var B=t.contentWindow.document.documentElement?eB(e,getComputedStyle(t.contentWindow.document.documentElement).backgroundColor):en.TRANSPARENT,n=t.contentWindow.document.body?eB(e,getComputedStyle(t.contentWindow.document.body).backgroundColor):en.TRANSPARENT;r.backgroundColor=A1(B)?A1(n)?r.styles.backgroundColor:n:B}}catch(s){}return r}return s(e,A),e}(t0),BA=["OL","UL","MENU"],Be=function(A,e,t,r){for(var B=e.firstChild,n=void 0;B;B=n)if(n=B.nextSibling,Bs(B)&&B.data.trim().length>0)t.textNodes.push(new rJ(A,B,t.styles));else if(Bo(B)){if(BH(B)&&B.assignedNodes)B.assignedNodes().forEach(function(e){return Be(A,e,t,r)});else{var s=Bt(A,B);!s.styles.isVisible()||(BB(B,s,r)?s.flags|=4:Bn(s.styles)&&(s.flags|=2),-1!==BA.indexOf(B.tagName)&&(s.flags|=8),t.elements.push(s),B.slot,B.shadowRoot?Be(A,B.shadowRoot,s,r):Bd(B)||Bw(B)||Bf(B)||Be(A,B,s,r))}}},Bt=function(A,e){return BC(e)?new r_(A,e):Bu(e)?new rq(A,e):Bw(e)?new rj(A,e):Ba(e)?new rz(A,e):Bc(e)?new r$(A,e):Bg(e)?new r6(A,e):Bf(e)?new r8(A,e):Bd(e)?new r7(A,e):BF(e)?new r9(A,e):new t0(A,e)},Br=function(A,e){var t=Bt(A,e);return t.flags|=4,Be(A,e,t,t),t},BB=function(A,e,t){return e.styles.isPositionedWithZIndex()||e.styles.opacity<1||e.styles.isTransformed()||Bl(A)&&t.styles.isTransparent()},Bn=function(A){return A.isPositioned()||A.isFloating()},Bs=function(A){return A.nodeType===Node.TEXT_NODE},Bo=function(A){return A.nodeType===Node.ELEMENT_NODE},Bi=function(A){return Bo(A)&&void 0!==A.style&&!BQ(A)},BQ=function(A){return"object"==typeof A.className},Ba=function(A){return"LI"===A.tagName},Bc=function(A){return"OL"===A.tagName},Bg=function(A){return"INPUT"===A.tagName},Bw=function(A){return"svg"===A.tagName},Bl=function(A){return"BODY"===A.tagName},Bu=function(A){return"CANVAS"===A.tagName},BU=function(A){return"VIDEO"===A.tagName},BC=function(A){return"IMG"===A.tagName},BF=function(A){return"IFRAME"===A.tagName},Bh=function(A){return"STYLE"===A.tagName},Bd=function(A){return"TEXTAREA"===A.tagName},Bf=function(A){return"SELECT"===A.tagName},BH=function(A){return"SLOT"===A.tagName},Bp=function(A){return A.tagName.indexOf("-")>0},BE=function(){function A(){this.counters={}}return A.prototype.getCounterValue=function(A){var e=this.counters[A];return e&&e.length?e[e.length-1]:1},A.prototype.getCounterValues=function(A){var e;return this.counters[A]||[]},A.prototype.pop=function(A){var e=this;A.forEach(function(A){return e.counters[A].pop()})},A.prototype.parse=function(A){var e=this,t=A.counterIncrement,r=A.counterReset,B=!0;null!==t&&t.forEach(function(A){var t=e.counters[A.counter];t&&0!==A.increment&&(B=!1,t.length||t.push(1),t[Math.max(0,t.length-1)]+=A.increment)});var n=[];return B&&r.forEach(function(A){var t=e.counters[A.counter];n.push(A.counter),t||(t=e.counters[A.counter]=[]),t.push(A.reset)}),n},A}(),BI={integers:[1e3,900,500,400,100,90,50,40,10,9,5,4,1],values:["M","CM","D","CD","C","XC","L","XL","X","IX","V","IV","I"]},By={integers:[9e3,8e3,7e3,6e3,5e3,4e3,3e3,2e3,1e3,900,800,700,600,500,400,300,200,100,90,80,70,60,50,40,30,20,10,9,8,7,6,5,4,3,2,1],values:["Ք","Փ","Ւ","Ց","Ր","Տ","Վ","Ս","Ռ","Ջ","Պ","Չ","Ո","Շ","Ն","Յ","Մ","Ճ","Ղ","Ձ","Հ","Կ","Ծ","Խ","Լ","Ի","Ժ","Թ","Ը","Է","Զ","Ե","Դ","Գ","Բ","Ա"]},BK={integers:[1e4,9e3,8e3,7e3,6e3,5e3,4e3,3e3,2e3,1e3,400,300,200,100,90,80,70,60,50,40,30,20,19,18,17,16,15,10,9,8,7,6,5,4,3,2,1],values:["י׳","ט׳","ח׳","ז׳","ו׳","ה׳","ד׳","ג׳","ב׳","א׳","ת","ש","ר","ק","צ","פ","ע","ס","נ","מ","ל","כ","יט","יח","יז","טז","טו","י","ט","ח","ז","ו","ה","ד","ג","ב","א"]},Bm={integers:[1e4,9e3,8e3,7e3,6e3,5e3,4e3,3e3,2e3,1e3,900,800,700,600,500,400,300,200,100,90,80,70,60,50,40,30,20,10,9,8,7,6,5,4,3,2,1],values:["ჵ","ჰ","ჯ","ჴ","ხ","ჭ","წ","ძ","ც","ჩ","შ","ყ","ღ","ქ","ფ","ჳ","ტ","ს","რ","ჟ","პ","ო","ჲ","ნ","მ","ლ","კ","ი","თ","ჱ","ზ","ვ","ე","დ","გ","ბ","ა"]},BL=function(A,e,t,r,B,n){return A<e||A>t?BO(A,B,n.length>0):r.integers.reduce(function(e,t,B){for(;A>=t;)A-=t,e+=r.values[B];return e},"")+n},Bv=function(A,e,t,r){var B="";do!t&&A--,B=r(A)+B,A/=e;while(A*e>=e);return B},Bb=function(A,e,t,r,B){var n=t-e+1;return(A<0?"-":"")+(Bv(Math.abs(A),n,r,function(A){return u(Math.floor(A%n)+e)})+B)},BD=function(A,e,t){void 0===t&&(t=". ");var r=e.length;return Bv(Math.abs(A),r,!1,function(A){return e[Math.floor(A%r)]})+t},Bx=function(A,e,t,r,B,n){if(A<-9999||A>9999)return BO(A,4,B.length>0);var s=Math.abs(A),o=B;if(0===s)return e[0]+o;for(var i=0;s>0&&i<=4;i++){var Q=s%10;0===Q&&tG(n,1)&&""!==o?o=e[Q]+o:Q>1||1===Q&&0===i||1===Q&&1===i&&tG(n,2)||1===Q&&1===i&&tG(n,4)&&A>100||1===Q&&i>1&&tG(n,8)?o=e[Q]+(i>0?t[i-1]:"")+o:1===Q&&i>0&&(o=t[i-1]+o),s=Math.floor(s/10)}return(A<0?r:"")+o},BM="十百千萬",BS="拾佰仟萬",BT="マイナス",BG="마이너스",BO=function(A,e,t){var r=t?". ":"",B=t?"、":"",n=t?", ":"",s=t?" ":"";switch(e){case 0:return"•"+s;case 1:return"◦"+s;case 2:return"◾"+s;case 5:var o=Bb(A,48,57,!0,r);return o.length<4?"0"+o:o;case 4:return BD(A,"〇一二三四五六七八九",B);case 6:return BL(A,1,3999,BI,3,r).toLowerCase();case 7:return BL(A,1,3999,BI,3,r);case 8:return Bb(A,945,969,!1,r);case 9:return Bb(A,97,122,!1,r);case 10:return Bb(A,65,90,!1,r);case 11:return Bb(A,1632,1641,!0,r);case 12:case 49:return BL(A,1,9999,By,3,r);case 35:return BL(A,1,9999,By,3,r).toLowerCase();case 13:return Bb(A,2534,2543,!0,r);case 14:case 30:return Bb(A,6112,6121,!0,r);case 15:return BD(A,"子丑寅卯辰巳午未申酉戌亥",B);case 16:return BD(A,"甲乙丙丁戊己庚辛壬癸",B);case 17:case 48:return Bx(A,"零一二三四五六七八九",BM,"負",B,14);case 47:return Bx(A,"零壹貳參肆伍陸柒捌玖",BS,"負",B,15);case 42:return Bx(A,"零一二三四五六七八九",BM,"负",B,14);case 41:return Bx(A,"零壹贰叁肆伍陆柒捌玖",BS,"负",B,15);case 26:return Bx(A,"〇一二三四五六七八九","十百千万",BT,B,0);case 25:return Bx(A,"零壱弐参四伍六七八九","拾百千万",BT,B,7);case 31:return Bx(A,"영일이삼사오육칠팔구","십백천만",BG,n,7);case 33:return Bx(A,"零一二三四五六七八九","十百千萬",BG,n,0);case 32:return Bx(A,"零壹貳參四五六七八九","拾百千",BG,n,7);case 18:return Bb(A,2406,2415,!0,r);case 20:return BL(A,1,19999,Bm,3,r);case 21:return Bb(A,2790,2799,!0,r);case 22:return Bb(A,2662,2671,!0,r);case 22:return BL(A,1,10999,BK,3,r);case 23:return BD(A,"あいうえおかきくけこさしすせそたちつてとなにぬねのはひふへほまみむめもやゆよらりるれろわゐゑをん");case 24:return BD(A,"いろはにほへとちりぬるをわかよたれそつねならむうゐのおくやまけふこえてあさきゆめみしゑひもせす");case 27:return Bb(A,3302,3311,!0,r);case 28:return BD(A,"アイウエオカキクケコサシスセソタチツテトナニヌネノハヒフヘホマミムメモヤユヨラリルレロワヰヱヲン",B);case 29:return BD(A,"イロハニホヘトチリヌルヲワカヨタレソツネナラムウヰノオクヤマケフコエテアサキユメミシヱヒモセス",B);case 34:return Bb(A,3792,3801,!0,r);case 37:return Bb(A,6160,6169,!0,r);case 38:return Bb(A,4160,4169,!0,r);case 39:return Bb(A,2918,2927,!0,r);case 40:return Bb(A,1776,1785,!0,r);case 43:return Bb(A,3046,3055,!0,r);case 44:return Bb(A,3174,3183,!0,r);case 45:return Bb(A,3664,3673,!0,r);case 46:return Bb(A,3872,3881,!0,r);default:return Bb(A,48,57,!0,r)}},BV="data-html2canvas-ignore",Bk=function(){function A(A,e,t){if(this.context=A,this.options=t,this.scrolledElements=[],this.referenceElement=e,this.counters=new BE,this.quoteDepth=0,!e.ownerDocument)throw Error("Cloned element does not have an owner document");this.documentElement=this.cloneNode(e.ownerDocument.documentElement,!1)}return A.prototype.toIFrame=function(A,e){var t=this,r=BN(A,e);if(!r.contentWindow)return Promise.reject("Unable to find iframe window");var B=A.defaultView.pageXOffset,n=A.defaultView.pageYOffset,s=r.contentWindow,o=s.document,a=BJ(r).then(function(){return i(t,void 0,void 0,function(){var A,t;return Q(this,function(B){switch(B.label){case 0:if(this.scrolledElements.forEach(Bq),s&&(s.scrollTo(e.left,e.top),/(iPad|iPhone|iPod)/g.test(navigator.userAgent)&&(s.scrollY!==e.top||s.scrollX!==e.left)&&(this.context.logger.warn("Unable to restore scroll position for cloned document"),this.context.windowBounds=this.context.windowBounds.add(s.scrollX-e.left,s.scrollY-e.top,0,0))),A=this.options.onclone,void 0===(t=this.clonedReferenceElement))return[2,Promise.reject("Error finding the "+this.referenceElement.nodeName+" in the cloned document")];if(!(o.fonts&&o.fonts.ready))return[3,2];return[4,o.fonts.ready];case 1:B.sent(),B.label=2;case 2:if(!/(AppleWebKit)/g.test(navigator.userAgent))return[3,4];return[4,BX(o)];case 3:B.sent(),B.label=4;case 4:if("function"==typeof A)return[2,Promise.resolve().then(function(){return A(o,t)}).then(function(){return r})];return[2,r]}})})});return o.open(),o.write(BZ(document.doctype)+"<html></html>"),B_(this.referenceElement.ownerDocument,B,n),o.replaceChild(o.adoptNode(this.documentElement),o.documentElement),o.close(),a},A.prototype.createElementClone=function(A){if(t$(A,2),Bu(A))return this.createCanvasClone(A);if(BU(A))return this.createVideoClone(A);if(Bh(A))return this.createStyleClone(A);var e=A.cloneNode(!1);return(BC(e)&&(BC(A)&&A.currentSrc&&A.currentSrc!==A.src&&(e.src=A.currentSrc,e.srcset=""),"lazy"===e.loading&&(e.loading="eager")),Bp(e))?this.createCustomElementClone(e):e},A.prototype.createCustomElementClone=function(A){var e=document.createElement("html2canvascustomelement");return BW(A.style,e),e},A.prototype.createStyleClone=function(A){try{var e=A.sheet;if(e&&e.cssRules){var t=[].slice.call(e.cssRules,0).reduce(function(A,e){return e&&"string"==typeof e.cssText?A+e.cssText:A},""),r=A.cloneNode(!1);return r.textContent=t,r}}catch(B){if(this.context.logger.error("Unable to access cssRules property",B),"SecurityError"!==B.name)throw B}return A.cloneNode(!1)},A.prototype.createCanvasClone=function(A){if(this.options.inlineImages&&A.ownerDocument){var e,t=A.ownerDocument.createElement("img");try{return t.src=A.toDataURL(),t}catch(r){this.context.logger.info("Unable to inline canvas contents, canvas is tainted",A)}}var B=A.cloneNode(!1);try{B.width=A.width,B.height=A.height;var n=A.getContext("2d"),s=B.getContext("2d");if(s){if(!this.options.allowTaint&&n)s.putImageData(n.getImageData(0,0,A.width,A.height),0,0);else{var o=null!==(e=A.getContext("webgl2"))&&void 0!==e?e:A.getContext("webgl");if(o){var i=o.getContextAttributes();(null==i?void 0:i.preserveDrawingBuffer)===!1&&this.context.logger.warn("Unable to clone WebGL context as it has preserveDrawingBuffer=false",A)}s.drawImage(A,0,0)}}}catch(Q){this.context.logger.info("Unable to clone canvas as it is tainted",A)}return B},A.prototype.createVideoClone=function(A){var e=A.ownerDocument.createElement("canvas");e.width=A.offsetWidth,e.height=A.offsetHeight;var t=e.getContext("2d");try{return t&&(t.drawImage(A,0,0,e.width,e.height),this.options.allowTaint||t.getImageData(0,0,e.width,e.height)),e}catch(r){this.context.logger.info("Unable to clone video as it is tainted",A)}var B=A.ownerDocument.createElement("canvas");return B.width=A.offsetWidth,B.height=A.offsetHeight,B},A.prototype.appendChildNode=function(A,e,t){var r;(!Bo(e)||"SCRIPT"!==e.tagName&&!e.hasAttribute(BV)&&("function"!=typeof this.options.ignoreElements||!this.options.ignoreElements(e)))&&(this.options.copyStyles&&Bo(e)&&Bh(e)||A.appendChild(this.cloneNode(e,t)))},A.prototype.cloneChildNodes=function(A,e,t){for(var r=this,B=A.shadowRoot?A.shadowRoot.firstChild:A.firstChild;B;B=B.nextSibling)if(Bo(B)&&BH(B)&&"function"==typeof B.assignedNodes){var n=B.assignedNodes();n.length&&n.forEach(function(A){return r.appendChildNode(e,A,t)})}else this.appendChildNode(e,B,t)},A.prototype.cloneNode=function(A,e){if(Bs(A))return document.createTextNode(A.data);if(!A.ownerDocument)return A.cloneNode(!1);var t=A.ownerDocument.defaultView;if(t&&Bo(A)&&(Bi(A)||BQ(A))){var B=this.createElementClone(A);B.style.transitionProperty="none";var n=t.getComputedStyle(A),s=t.getComputedStyle(A,":before"),o=t.getComputedStyle(A,":after");this.referenceElement===A&&Bi(B)&&(this.clonedReferenceElement=B),Bl(B)&&B0(B);var i=this.counters.parse(new tq(this.context,n)),Q=this.resolvePseudoContent(A,B,s,r.BEFORE);Bp(A)&&(e=!0),BU(A)||this.cloneChildNodes(A,B,e),Q&&B.insertBefore(Q,B.firstChild);var a=this.resolvePseudoContent(A,B,o,r.AFTER);return a&&B.appendChild(a),this.counters.pop(i),(n&&(this.options.copyStyles||BQ(A))&&!BF(A)||e)&&BW(n,B),(0!==A.scrollTop||0!==A.scrollLeft)&&this.scrolledElements.push([B,A.scrollLeft,A.scrollTop]),(Bd(A)||Bf(A))&&(Bd(B)||Bf(B))&&(B.value=A.value),B}return A.cloneNode(!1)},A.prototype.resolvePseudoContent=function(A,e,t,B){var n=this;if(t){var s=t.content,o=e.ownerDocument;if(o&&s&&"none"!==s&&"-moz-alt-content"!==s&&"none"!==t.display){this.counters.parse(new tq(this.context,t));var i=new t_(this.context,t),Q=o.createElement("html2canvaspseudoelement");BW(t,Q),i.content.forEach(function(e){if(0===e.type)Q.appendChild(o.createTextNode(e.value));else if(22===e.type){var t=o.createElement("img");t.src=e.value,t.style.opacity="1",Q.appendChild(t)}else if(18===e.type){if("attr"===e.name){var r=e.values.filter(AM);r.length&&Q.appendChild(o.createTextNode(A.getAttribute(r[0].value)||""))}else if("counter"===e.name){var B=e.values.filter(AO),s=B[0],a=B[1];if(s&&AM(s)){var c=n.counters.getCounterValue(s.value),g=a&&AM(a)?tr.parse(n.context,a.value):3;Q.appendChild(o.createTextNode(BO(c,g,!1)))}}else if("counters"===e.name){var w=e.values.filter(AO),s=w[0],l=w[1],a=w[2];if(s&&AM(s)){var u=n.counters.getCounterValues(s.value),U=a&&AM(a)?tr.parse(n.context,a.value):3,C=l&&0===l.type?l.value:"",F=u.map(function(A){return BO(A,U,!1)}).join(C);Q.appendChild(o.createTextNode(F))}}}else if(20===e.type)switch(e.value){case"open-quote":Q.appendChild(o.createTextNode(tP(i.quotes,n.quoteDepth++,!0)));break;case"close-quote":Q.appendChild(o.createTextNode(tP(i.quotes,--n.quoteDepth,!1)));break;default:Q.appendChild(o.createTextNode(e.value))}}),Q.className=Bj+" "+Bz;var a=B===r.BEFORE?" "+Bj:" "+Bz;return BQ(e)?e.className.baseValue+=a:e.className+=a,Q}}},A.destroy=function(A){return!!A.parentNode&&(A.parentNode.removeChild(A),!0)},A}();(rQ=r||(r={}))[rQ.BEFORE=0]="BEFORE",rQ[rQ.AFTER=1]="AFTER";var BR,BN=function(A,e){var t=A.createElement("iframe");return t.className="html2canvas-container",t.style.visibility="hidden",t.style.position="fixed",t.style.left="-10000px",t.style.top="0px",t.style.border="0",t.width=e.width.toString(),t.height=e.height.toString(),t.scrolling="no",t.setAttribute(BV,"true"),A.body.appendChild(t),t},BP=function(A){return new Promise(function(e){if(A.complete||!A.src){e();return}A.onload=e,A.onerror=e})},BX=function(A){return Promise.all([].slice.call(A.images,0).map(BP))},BJ=function(A){return new Promise(function(e,t){var r=A.contentWindow;if(!r)return t("No window assigned for iframe");var B=r.document;r.onload=A.onload=function(){r.onload=A.onload=null;var t=setInterval(function(){B.body.childNodes.length>0&&"complete"===B.readyState&&(clearInterval(t),e(A))},50)}})},BY=["all","d","content"],BW=function(A,e){for(var t=A.length-1;t>=0;t--){var r=A.item(t);-1===BY.indexOf(r)&&e.style.setProperty(r,A.getPropertyValue(r))}return e},BZ=function(A){var e="";return A&&(e+="<!DOCTYPE ",A.name&&(e+=A.name),A.internalSubset&&(e+=A.internalSubset),A.publicId&&(e+='"'+A.publicId+'"'),A.systemId&&(e+='"'+A.systemId+'"'),e+=">"),e},B_=function(A,e,t){A&&A.defaultView&&(e!==A.defaultView.pageXOffset||t!==A.defaultView.pageYOffset)&&A.defaultView.scrollTo(e,t)},Bq=function(A){var e=A[0],t=A[1],r=A[2];e.scrollLeft=t,e.scrollTop=r},Bj="___html2canvas___pseudoelement_before",Bz="___html2canvas___pseudoelement_after",B$='{\n    content: "" !important;\n    display: none !important;\n}',B0=function(A){B4(A,"."+Bj+":before"+B$+"\n         ."+Bz+":after"+B$)},B4=function(A,e){var t=A.ownerDocument;if(t){var r=t.createElement("style");r.textContent=e,A.appendChild(r)}},B1=function(){function A(){}return A.getOrigin=function(e){var t=A._link;return t?(t.href=e,t.href=t.href,t.protocol+t.hostname+t.port):"about:blank"},A.isSameOrigin=function(e){return A.getOrigin(e)===A._origin},A.setContext=function(e){A._link=e.document.createElement("a"),A._origin=A.getOrigin(e.location.href)},A._origin="about:blank",A}(),B2=function(){function A(A,e){this.context=A,this._options=e,this._cache={}}return A.prototype.addImage=function(A){var e=Promise.resolve();return this.has(A)||(nA(A)||B8(A))&&(this._cache[A]=this.loadImage(A)).catch(function(){}),e},A.prototype.match=function(A){return this._cache[A]},A.prototype.loadImage=function(A){return i(this,void 0,void 0,function(){var e,t,r,B,n=this;return Q(this,function(s){switch(s.label){case 0:if(e=B1.isSameOrigin(A),t=!B7(A)&&!0===this._options.useCORS&&rd.SUPPORT_CORS_IMAGES&&!e,r=!B7(A)&&!e&&!nA(A)&&"string"==typeof this._options.proxy&&rd.SUPPORT_CORS_XHR&&!t,!e&&!1===this._options.allowTaint&&!B7(A)&&!nA(A)&&!r&&!t)return[2];if(B=A,!r)return[3,2];return[4,this.proxy(B)];case 1:B=s.sent(),s.label=2;case 2:return this.context.logger.debug("Added image "+A.substring(0,256)),[4,new Promise(function(A,e){var r=new Image;r.onload=function(){return A(r)},r.onerror=e,(B9(B)||t)&&(r.crossOrigin="anonymous"),r.src=B,!0===r.complete&&setTimeout(function(){return A(r)},500),n._options.imageTimeout>0&&setTimeout(function(){return e("Timed out ("+n._options.imageTimeout+"ms) loading image")},n._options.imageTimeout)})];case 3:return[2,s.sent()]}})})},A.prototype.has=function(A){return void 0!==this._cache[A]},A.prototype.keys=function(){return Promise.resolve(Object.keys(this._cache))},A.prototype.proxy=function(A){var e=this,t=this._options.proxy;if(!t)throw Error("No proxy defined");var r=A.substring(0,256);return new Promise(function(B,n){var s=rd.SUPPORT_RESPONSE_TYPE?"blob":"text",o=new XMLHttpRequest;o.onload=function(){if(200===o.status){if("text"===s)B(o.response);else{var A=new FileReader;A.addEventListener("load",function(){return B(A.result)},!1),A.addEventListener("error",function(A){return n(A)},!1),A.readAsDataURL(o.response)}}else n("Failed to proxy resource "+r+" with status code "+o.status)},o.onerror=n;var i=t.indexOf("?")>-1?"&":"?";if(o.open("GET",""+t+i+"url="+encodeURIComponent(A)+"&responseType="+s),"text"!==s&&o instanceof XMLHttpRequest&&(o.responseType=s),e._options.imageTimeout){var Q=e._options.imageTimeout;o.timeout=Q,o.ontimeout=function(){return n("Timed out ("+Q+"ms) proxying "+r)}}o.send()})},A}(),B3=/^data:image\/svg\+xml/i,B5=/^data:image\/.*;base64,/i,B6=/^data:image\/.*/i,B8=function(A){return rd.SUPPORT_SVG_DRAWING||!ne(A)},B7=function(A){return B6.test(A)},B9=function(A){return B5.test(A)},nA=function(A){return"blob"===A.substr(0,4)},ne=function(A){return"svg"===A.substr(-3).toLowerCase()||B3.test(A)},nt=function(){function A(A,e){this.type=0,this.x=A,this.y=e}return A.prototype.add=function(e,t){return new A(this.x+e,this.y+t)},A}(),nr=function(A,e,t){return new nt(A.x+(e.x-A.x)*t,A.y+(e.y-A.y)*t)},nB=function(){function A(A,e,t,r){this.type=1,this.start=A,this.startControl=e,this.endControl=t,this.end=r}return A.prototype.subdivide=function(e,t){var r=nr(this.start,this.startControl,e),B=nr(this.startControl,this.endControl,e),n=nr(this.endControl,this.end,e),s=nr(r,B,e),o=nr(B,n,e),i=nr(s,o,e);return t?new A(this.start,r,s,i):new A(i,o,n,this.end)},A.prototype.add=function(e,t){return new A(this.start.add(e,t),this.startControl.add(e,t),this.endControl.add(e,t),this.end.add(e,t))},A.prototype.reverse=function(){return new A(this.end,this.endControl,this.startControl,this.start)},A}(),nn=function(A){return 1===A.type},ns=function(A){var e=A.styles,t=A.bounds,r=AW(e.borderTopLeftRadius,t.width,t.height),n=r[0],s=r[1],o=AW(e.borderTopRightRadius,t.width,t.height),i=o[0],Q=o[1],a=AW(e.borderBottomRightRadius,t.width,t.height),c=a[0],g=a[1],w=AW(e.borderBottomLeftRadius,t.width,t.height),l=w[0],u=w[1],U=[];U.push((n+i)/t.width),U.push((l+c)/t.width),U.push((s+u)/t.height),U.push((Q+g)/t.height);var C=Math.max.apply(Math,U);C>1&&(n/=C,s/=C,i/=C,Q/=C,c/=C,g/=C,l/=C,u/=C);var F=t.width-i,h=t.height-g,d=t.width-c,f=t.height-u,H=e.borderTopWidth,p=e.borderRightWidth,E=e.borderBottomWidth,I=e.borderLeftWidth,y=AZ(e.paddingTop,A.bounds.width),K=AZ(e.paddingRight,A.bounds.width),m=AZ(e.paddingBottom,A.bounds.width),L=AZ(e.paddingLeft,A.bounds.width);this.topLeftBorderDoubleOuterBox=n>0||s>0?no(t.left+I/3,t.top+H/3,n-I/3,s-H/3,B.TOP_LEFT):new nt(t.left+I/3,t.top+H/3),this.topRightBorderDoubleOuterBox=n>0||s>0?no(t.left+F,t.top+H/3,i-p/3,Q-H/3,B.TOP_RIGHT):new nt(t.left+t.width-p/3,t.top+H/3),this.bottomRightBorderDoubleOuterBox=c>0||g>0?no(t.left+d,t.top+h,c-p/3,g-E/3,B.BOTTOM_RIGHT):new nt(t.left+t.width-p/3,t.top+t.height-E/3),this.bottomLeftBorderDoubleOuterBox=l>0||u>0?no(t.left+I/3,t.top+f,l-I/3,u-E/3,B.BOTTOM_LEFT):new nt(t.left+I/3,t.top+t.height-E/3),this.topLeftBorderDoubleInnerBox=n>0||s>0?no(t.left+2*I/3,t.top+2*H/3,n-2*I/3,s-2*H/3,B.TOP_LEFT):new nt(t.left+2*I/3,t.top+2*H/3),this.topRightBorderDoubleInnerBox=n>0||s>0?no(t.left+F,t.top+2*H/3,i-2*p/3,Q-2*H/3,B.TOP_RIGHT):new nt(t.left+t.width-2*p/3,t.top+2*H/3),this.bottomRightBorderDoubleInnerBox=c>0||g>0?no(t.left+d,t.top+h,c-2*p/3,g-2*E/3,B.BOTTOM_RIGHT):new nt(t.left+t.width-2*p/3,t.top+t.height-2*E/3),this.bottomLeftBorderDoubleInnerBox=l>0||u>0?no(t.left+2*I/3,t.top+f,l-2*I/3,u-2*E/3,B.BOTTOM_LEFT):new nt(t.left+2*I/3,t.top+t.height-2*E/3),this.topLeftBorderStroke=n>0||s>0?no(t.left+I/2,t.top+H/2,n-I/2,s-H/2,B.TOP_LEFT):new nt(t.left+I/2,t.top+H/2),this.topRightBorderStroke=n>0||s>0?no(t.left+F,t.top+H/2,i-p/2,Q-H/2,B.TOP_RIGHT):new nt(t.left+t.width-p/2,t.top+H/2),this.bottomRightBorderStroke=c>0||g>0?no(t.left+d,t.top+h,c-p/2,g-E/2,B.BOTTOM_RIGHT):new nt(t.left+t.width-p/2,t.top+t.height-E/2),this.bottomLeftBorderStroke=l>0||u>0?no(t.left+I/2,t.top+f,l-I/2,u-E/2,B.BOTTOM_LEFT):new nt(t.left+I/2,t.top+t.height-E/2),this.topLeftBorderBox=n>0||s>0?no(t.left,t.top,n,s,B.TOP_LEFT):new nt(t.left,t.top),this.topRightBorderBox=i>0||Q>0?no(t.left+F,t.top,i,Q,B.TOP_RIGHT):new nt(t.left+t.width,t.top),this.bottomRightBorderBox=c>0||g>0?no(t.left+d,t.top+h,c,g,B.BOTTOM_RIGHT):new nt(t.left+t.width,t.top+t.height),this.bottomLeftBorderBox=l>0||u>0?no(t.left,t.top+f,l,u,B.BOTTOM_LEFT):new nt(t.left,t.top+t.height),this.topLeftPaddingBox=n>0||s>0?no(t.left+I,t.top+H,Math.max(0,n-I),Math.max(0,s-H),B.TOP_LEFT):new nt(t.left+I,t.top+H),this.topRightPaddingBox=i>0||Q>0?no(t.left+Math.min(F,t.width-p),t.top+H,F>t.width+p?0:Math.max(0,i-p),Math.max(0,Q-H),B.TOP_RIGHT):new nt(t.left+t.width-p,t.top+H),this.bottomRightPaddingBox=c>0||g>0?no(t.left+Math.min(d,t.width-I),t.top+Math.min(h,t.height-E),Math.max(0,c-p),Math.max(0,g-E),B.BOTTOM_RIGHT):new nt(t.left+t.width-p,t.top+t.height-E),this.bottomLeftPaddingBox=l>0||u>0?no(t.left+I,t.top+Math.min(f,t.height-E),Math.max(0,l-I),Math.max(0,u-E),B.BOTTOM_LEFT):new nt(t.left+I,t.top+t.height-E),this.topLeftContentBox=n>0||s>0?no(t.left+I+L,t.top+H+y,Math.max(0,n-(I+L)),Math.max(0,s-(H+y)),B.TOP_LEFT):new nt(t.left+I+L,t.top+H+y),this.topRightContentBox=i>0||Q>0?no(t.left+Math.min(F,t.width+I+L),t.top+H+y,F>t.width+I+L?0:i-I+L,Q-(H+y),B.TOP_RIGHT):new nt(t.left+t.width-(p+K),t.top+H+y),this.bottomRightContentBox=c>0||g>0?no(t.left+Math.min(d,t.width-(I+L)),t.top+Math.min(h,t.height+H+y),Math.max(0,c-(p+K)),g-(E+m),B.BOTTOM_RIGHT):new nt(t.left+t.width-(p+K),t.top+t.height-(E+m)),this.bottomLeftContentBox=l>0||u>0?no(t.left+I+L,t.top+f,Math.max(0,l-(I+L)),u-(E+m),B.BOTTOM_LEFT):new nt(t.left+I+L,t.top+t.height-(E+m))};(BR=B||(B={}))[BR.TOP_LEFT=0]="TOP_LEFT",BR[BR.TOP_RIGHT=1]="TOP_RIGHT",BR[BR.BOTTOM_RIGHT=2]="BOTTOM_RIGHT",BR[BR.BOTTOM_LEFT=3]="BOTTOM_LEFT";var no=function(A,e,t,r,n){var s=4*((Math.sqrt(2)-1)/3),o=t*s,i=r*s,Q=A+t,a=e+r;switch(n){case B.TOP_LEFT:return new nB(new nt(A,a),new nt(A,a-i),new nt(Q-o,e),new nt(Q,e));case B.TOP_RIGHT:return new nB(new nt(A,e),new nt(A+o,e),new nt(Q,a-i),new nt(Q,a));case B.BOTTOM_RIGHT:return new nB(new nt(Q,e),new nt(Q,e+i),new nt(A+o,a),new nt(A,a));case B.BOTTOM_LEFT:default:return new nB(new nt(Q,a),new nt(Q-o,a),new nt(A,e+i),new nt(A,e))}},ni=function(A){return[A.topLeftBorderBox,A.topRightBorderBox,A.bottomRightBorderBox,A.bottomLeftBorderBox]},nQ=function(A){return[A.topLeftPaddingBox,A.topRightPaddingBox,A.bottomRightPaddingBox,A.bottomLeftPaddingBox]},na=function(A,e,t){this.offsetX=A,this.offsetY=e,this.matrix=t,this.type=0,this.target=6},nc=function(A,e){this.path=A,this.target=e,this.type=1},ng=function(A){this.opacity=A,this.type=2,this.target=6},nw=function(A){return 1===A.type},nl=function(A,e){return A.length===e.length&&A.some(function(A,t){return A===e[t]})},nu=function(A){this.element=A,this.inlineLevel=[],this.nonInlineLevel=[],this.negativeZIndex=[],this.zeroOrAutoZIndexOrTransformedOrOpacity=[],this.positiveZIndex=[],this.nonPositionedFloats=[],this.nonPositionedInlineLevel=[]},nU=function(){function A(A,e){if(this.container=A,this.parent=e,this.effects=[],this.curves=new ns(this.container),this.container.styles.opacity<1&&this.effects.push(new ng(this.container.styles.opacity)),null!==this.container.styles.transform){var t=this.container.bounds.left+this.container.styles.transformOrigin[0].number,r=this.container.bounds.top+this.container.styles.transformOrigin[1].number,B=this.container.styles.transform;this.effects.push(new na(t,r,B))}if(0!==this.container.styles.overflowX){var n=ni(this.curves),s=nQ(this.curves);nl(n,s)?this.effects.push(new nc(n,6)):(this.effects.push(new nc(n,2)),this.effects.push(new nc(s,4)))}}return A.prototype.getEffects=function(A){for(var e=-1===[2,3].indexOf(this.container.styles.position),t=this.parent,r=this.effects.slice(0);t;){var B=t.effects.filter(function(A){return!nw(A)});if(e||0!==t.container.styles.position||!t.parent){if(r.unshift.apply(r,B),e=-1===[2,3].indexOf(t.container.styles.position),0!==t.container.styles.overflowX){var n=ni(t.curves),s=nQ(t.curves);nl(n,s)||r.unshift(new nc(s,6))}}else r.unshift.apply(r,B);t=t.parent}return r.filter(function(e){return tG(e.target,A)})},A}(),nC=function(A,e,t,r){A.container.elements.forEach(function(B){var n=tG(B.flags,4),s=tG(B.flags,2),o=new nU(B,A);tG(B.styles.display,2048)&&r.push(o);var i=tG(B.flags,8)?[]:r;if(n||s){var Q=n||B.styles.isPositioned()?t:e,a=new nu(o);if(B.styles.isPositioned()||B.styles.opacity<1||B.styles.isTransformed()){var c=B.styles.zIndex.order;if(c<0){var g=0;Q.negativeZIndex.some(function(A,e){if(c>A.element.container.styles.zIndex.order)g=e;else if(g>0)return!0;return!1}),Q.negativeZIndex.splice(g,0,a)}else if(c>0){var w=0;Q.positiveZIndex.some(function(A,e){if(c>=A.element.container.styles.zIndex.order)w=e+1;else if(w>0)return!0;return!1}),Q.positiveZIndex.splice(w,0,a)}else Q.zeroOrAutoZIndexOrTransformedOrOpacity.push(a)}else B.styles.isFloating()?Q.nonPositionedFloats.push(a):Q.nonPositionedInlineLevel.push(a);nC(o,a,n?a:t,i)}else B.styles.isInlineLevel()?e.inlineLevel.push(o):e.nonInlineLevel.push(o),nC(o,e,t,i);tG(B.flags,8)&&nF(B,i)})},nF=function(A,e){for(var t=A instanceof r$?A.start:1,r=A instanceof r$&&A.reversed,B=0;B<e.length;B++){var n=e[B];n.container instanceof rz&&"number"==typeof n.container.value&&0!==n.container.value&&(t=n.container.value),n.listValue=BO(t,n.container.styles.listStyleType,!0),t+=r?-1:1}},nh=function(A){var e=new nU(A,null),t=new nu(e),r=[];return nC(e,t,t,r),nF(e.container,r),t},nd=function(A,e){switch(e){case 0:return nI(A.topLeftBorderBox,A.topLeftPaddingBox,A.topRightBorderBox,A.topRightPaddingBox);case 1:return nI(A.topRightBorderBox,A.topRightPaddingBox,A.bottomRightBorderBox,A.bottomRightPaddingBox);case 2:return nI(A.bottomRightBorderBox,A.bottomRightPaddingBox,A.bottomLeftBorderBox,A.bottomLeftPaddingBox);default:return nI(A.bottomLeftBorderBox,A.bottomLeftPaddingBox,A.topLeftBorderBox,A.topLeftPaddingBox)}},nf=function(A,e){switch(e){case 0:return nI(A.topLeftBorderBox,A.topLeftBorderDoubleOuterBox,A.topRightBorderBox,A.topRightBorderDoubleOuterBox);case 1:return nI(A.topRightBorderBox,A.topRightBorderDoubleOuterBox,A.bottomRightBorderBox,A.bottomRightBorderDoubleOuterBox);case 2:return nI(A.bottomRightBorderBox,A.bottomRightBorderDoubleOuterBox,A.bottomLeftBorderBox,A.bottomLeftBorderDoubleOuterBox);default:return nI(A.bottomLeftBorderBox,A.bottomLeftBorderDoubleOuterBox,A.topLeftBorderBox,A.topLeftBorderDoubleOuterBox)}},nH=function(A,e){switch(e){case 0:return nI(A.topLeftBorderDoubleInnerBox,A.topLeftPaddingBox,A.topRightBorderDoubleInnerBox,A.topRightPaddingBox);case 1:return nI(A.topRightBorderDoubleInnerBox,A.topRightPaddingBox,A.bottomRightBorderDoubleInnerBox,A.bottomRightPaddingBox);case 2:return nI(A.bottomRightBorderDoubleInnerBox,A.bottomRightPaddingBox,A.bottomLeftBorderDoubleInnerBox,A.bottomLeftPaddingBox);default:return nI(A.bottomLeftBorderDoubleInnerBox,A.bottomLeftPaddingBox,A.topLeftBorderDoubleInnerBox,A.topLeftPaddingBox)}},np=function(A,e){switch(e){case 0:return nE(A.topLeftBorderStroke,A.topRightBorderStroke);case 1:return nE(A.topRightBorderStroke,A.bottomRightBorderStroke);case 2:return nE(A.bottomRightBorderStroke,A.bottomLeftBorderStroke);default:return nE(A.bottomLeftBorderStroke,A.topLeftBorderStroke)}},nE=function(A,e){var t=[];return nn(A)?t.push(A.subdivide(.5,!1)):t.push(A),nn(e)?t.push(e.subdivide(.5,!0)):t.push(e),t},nI=function(A,e,t,r){var B=[];return nn(A)?B.push(A.subdivide(.5,!1)):B.push(A),nn(t)?B.push(t.subdivide(.5,!0)):B.push(t),nn(r)?B.push(r.subdivide(.5,!0).reverse()):B.push(r),nn(e)?B.push(e.subdivide(.5,!1).reverse()):B.push(e),B},ny=function(A){var e=A.bounds,t=A.styles;return e.add(t.borderLeftWidth,t.borderTopWidth,-(t.borderRightWidth+t.borderLeftWidth),-(t.borderTopWidth+t.borderBottomWidth))},nK=function(A){var e=A.styles,t=A.bounds,r=AZ(e.paddingLeft,t.width),B=AZ(e.paddingRight,t.width),n=AZ(e.paddingTop,t.width),s=AZ(e.paddingBottom,t.width);return t.add(r+e.borderLeftWidth,n+e.borderTopWidth,-(e.borderRightWidth+e.borderLeftWidth+r+B),-(e.borderTopWidth+e.borderBottomWidth+n+s))},nm=function(A,e,t){var r,B,n,s,o,i=0===(r=nD(A.styles.backgroundOrigin,e))?A.bounds:2===r?nK(A):ny(A),Q=0===(n=nD(A.styles.backgroundClip,e))?A.bounds:2===n?nK(A):ny(A),a=nb(nD(A.styles.backgroundSize,e),t,i),c=a[0],g=a[1],w=AW(nD(A.styles.backgroundPosition,e),i.width-c,i.height-g),l=nx(nD(A.styles.backgroundRepeat,e),w,a,i,Q);return[l,Math.round(i.left+w[0]),Math.round(i.top+w[1]),c,g]},nL=function(e){return AM(e)&&e.value===A.AUTO},nv=function(A){return"number"==typeof A},nb=function(e,t,r){var B=t[0],n=t[1],s=t[2],o=e[0],i=e[1];if(!o)return[0,0];if(AN(o)&&i&&AN(i))return[AZ(o,r.width),AZ(i,r.height)];var Q=nv(s);if(AM(o)&&(o.value===A.CONTAIN||o.value===A.COVER))return nv(s)?r.width/r.height<s!=(o.value===A.COVER)?[r.width,r.width/s]:[r.height*s,r.height]:[r.width,r.height];var a=nv(B),c=nv(n),g=a||c;if(nL(o)&&(!i||nL(i))){if(a&&c)return[B,n];if(!Q&&!g)return[r.width,r.height];if(g&&Q)return[a?B:n*s,c?n:B/s];var w=a?B:r.width,l=c?n:r.height;return[w,l]}if(Q){var u=0,U=0;return AN(o)?u=AZ(o,r.width):AN(i)&&(U=AZ(i,r.height)),nL(o)?u=U*s:(!i||nL(i))&&(U=u/s),[u,U]}var C=null,F=null;if(AN(o)?C=AZ(o,r.width):i&&AN(i)&&(F=AZ(i,r.height)),null!==C&&(!i||nL(i))&&(F=a&&c?C/B*n:r.height),null!==F&&nL(o)&&(C=a&&c?F/n*B:r.width),null!==C&&null!==F)return[C,F];throw Error("Unable to calculate background-size for element")},nD=function(A,e){var t=A[e];return void 0===t?A[0]:t},nx=function(A,e,t,r,B){var n=e[0],s=e[1],o=t[0],i=t[1];switch(A){case 2:return[new nt(Math.round(r.left),Math.round(r.top+s)),new nt(Math.round(r.left+r.width),Math.round(r.top+s)),new nt(Math.round(r.left+r.width),Math.round(i+r.top+s)),new nt(Math.round(r.left),Math.round(i+r.top+s))];case 3:return[new nt(Math.round(r.left+n),Math.round(r.top)),new nt(Math.round(r.left+n+o),Math.round(r.top)),new nt(Math.round(r.left+n+o),Math.round(r.height+r.top)),new nt(Math.round(r.left+n),Math.round(r.height+r.top))];case 1:return[new nt(Math.round(r.left+n),Math.round(r.top+s)),new nt(Math.round(r.left+n+o),Math.round(r.top+s)),new nt(Math.round(r.left+n+o),Math.round(r.top+s+i)),new nt(Math.round(r.left+n),Math.round(r.top+s+i))];default:return[new nt(Math.round(B.left),Math.round(B.top)),new nt(Math.round(B.left+B.width),Math.round(B.top)),new nt(Math.round(B.left+B.width),Math.round(B.height+B.top)),new nt(Math.round(B.left),Math.round(B.height+B.top))]}},nM="Hidden Text",nS=function(){function A(A){this._data={},this._document=A}return A.prototype.parseMetrics=function(A,e){var t=this._document.createElement("div"),r=this._document.createElement("img"),B=this._document.createElement("span"),n=this._document.body;t.style.visibility="hidden",t.style.fontFamily=A,t.style.fontSize=e,t.style.margin="0",t.style.padding="0",t.style.whiteSpace="nowrap",n.appendChild(t),r.src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7",r.width=1,r.height=1,r.style.margin="0",r.style.padding="0",r.style.verticalAlign="baseline",B.style.fontFamily=A,B.style.fontSize=e,B.style.margin="0",B.style.padding="0",B.appendChild(this._document.createTextNode(nM)),t.appendChild(B),t.appendChild(r);var s=r.offsetTop-B.offsetTop+2;t.removeChild(B),t.appendChild(this._document.createTextNode(nM)),t.style.lineHeight="normal",r.style.verticalAlign="super";var o=r.offsetTop-t.offsetTop+2;return n.removeChild(t),{baseline:s,middle:o}},A.prototype.getMetrics=function(A,e){var t=A+" "+e;return void 0===this._data[t]&&(this._data[t]=this.parseMetrics(A,e)),this._data[t]},A}(),nT=function(A,e){this.context=A,this.options=e},nG=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r._activeEffects=[],r.canvas=t.canvas?t.canvas:document.createElement("canvas"),r.ctx=r.canvas.getContext("2d"),t.canvas||(r.canvas.width=Math.floor(t.width*t.scale),r.canvas.height=Math.floor(t.height*t.scale),r.canvas.style.width=t.width+"px",r.canvas.style.height=t.height+"px"),r.fontMetrics=new nS(document),r.ctx.scale(r.options.scale,r.options.scale),r.ctx.translate(-t.x,-t.y),r.ctx.textBaseline="bottom",r._activeEffects=[],r.context.logger.debug("Canvas renderer initialized ("+t.width+"x"+t.height+") with scale "+t.scale),r}return s(e,A),e.prototype.applyEffects=function(A){for(var e=this;this._activeEffects.length;)this.popEffect();A.forEach(function(A){return e.applyEffect(A)})},e.prototype.applyEffect=function(A){var e,t;this.ctx.save(),2===A.type&&(this.ctx.globalAlpha=A.opacity),0===A.type&&(this.ctx.translate(A.offsetX,A.offsetY),this.ctx.transform(A.matrix[0],A.matrix[1],A.matrix[2],A.matrix[3],A.matrix[4],A.matrix[5]),this.ctx.translate(-A.offsetX,-A.offsetY)),nw(A)&&(this.path(A.path),this.ctx.clip()),this._activeEffects.push(A)},e.prototype.popEffect=function(){this._activeEffects.pop(),this.ctx.restore()},e.prototype.renderStack=function(A){return i(this,void 0,void 0,function(){var e;return Q(this,function(e){switch(e.label){case 0:if(!(0,A.element.container.styles).isVisible())return[3,2];return[4,this.renderStackContent(A)];case 1:e.sent(),e.label=2;case 2:return[2]}})})},e.prototype.renderNode=function(A){return i(this,void 0,void 0,function(){return Q(this,function(e){switch(e.label){case 0:if(tG(A.container.flags,16),!A.container.styles.isVisible())return[3,3];return[4,this.renderNodeBackgroundAndBorders(A)];case 1:return e.sent(),[4,this.renderNodeContent(A)];case 2:e.sent(),e.label=3;case 3:return[2]}})})},e.prototype.renderTextWithLetterSpacing=function(A,e,t){var r=this;0===e?this.ctx.fillText(A.text,A.bounds.left,A.bounds.top+t):rR(A.text).reduce(function(e,B){return r.ctx.fillText(B,e,A.bounds.top+t),e+r.ctx.measureText(B).width},A.bounds.left)},e.prototype.createFontStyle=function(A){var e=A.fontVariant.filter(function(A){return"normal"===A||"small-caps"===A}).join(""),t=nN(A.fontFamily).join(", "),r=AD(A.fontSize)?""+A.fontSize.number+A.fontSize.unit:A.fontSize.number+"px";return[[A.fontStyle,e,A.fontWeight,r,t].join(" "),t,r]},e.prototype.renderTextNode=function(A,e){return i(this,void 0,void 0,function(){var t,r,B,n,s,o,i,a,c=this;return Q(this,function(Q){return r=(t=this.createFontStyle(e))[0],B=t[1],n=t[2],this.ctx.font=r,this.ctx.direction=1===e.direction?"rtl":"ltr",this.ctx.textAlign="left",this.ctx.textBaseline="alphabetic",o=(s=this.fontMetrics.getMetrics(B,n)).baseline,i=s.middle,a=e.paintOrder,A.textBounds.forEach(function(A){a.forEach(function(t){switch(t){case 0:c.ctx.fillStyle=A2(e.color),c.renderTextWithLetterSpacing(A,e.letterSpacing,o);var r=e.textShadow;r.length&&A.text.trim().length&&(r.slice(0).reverse().forEach(function(t){c.ctx.shadowColor=A2(t.color),c.ctx.shadowOffsetX=t.offsetX.number*c.options.scale,c.ctx.shadowOffsetY=t.offsetY.number*c.options.scale,c.ctx.shadowBlur=t.blur.number,c.renderTextWithLetterSpacing(A,e.letterSpacing,o)}),c.ctx.shadowColor="",c.ctx.shadowOffsetX=0,c.ctx.shadowOffsetY=0,c.ctx.shadowBlur=0),e.textDecorationLine.length&&(c.ctx.fillStyle=A2(e.textDecorationColor||e.color),e.textDecorationLine.forEach(function(e){switch(e){case 1:c.ctx.fillRect(A.bounds.left,Math.round(A.bounds.top+o),A.bounds.width,1);break;case 2:c.ctx.fillRect(A.bounds.left,Math.round(A.bounds.top),A.bounds.width,1);break;case 3:c.ctx.fillRect(A.bounds.left,Math.ceil(A.bounds.top+i),A.bounds.width,1)}}));break;case 1:e.webkitTextStrokeWidth&&A.text.trim().length&&(c.ctx.strokeStyle=A2(e.webkitTextStrokeColor),c.ctx.lineWidth=e.webkitTextStrokeWidth,c.ctx.lineJoin=window.chrome?"miter":"round",c.ctx.strokeText(A.text,A.bounds.left,A.bounds.top+o)),c.ctx.strokeStyle="",c.ctx.lineWidth=0,c.ctx.lineJoin="miter"}})}),[2]})})},e.prototype.renderReplacedElement=function(A,e,t){if(t&&A.intrinsicWidth>0&&A.intrinsicHeight>0){var r=nK(A),B=nQ(e);this.path(B),this.ctx.save(),this.ctx.clip(),this.ctx.drawImage(t,0,0,A.intrinsicWidth,A.intrinsicHeight,r.left,r.top,r.width,r.height),this.ctx.restore()}},e.prototype.renderNodeContent=function(A){return i(this,void 0,void 0,function(){var t,r,B,n,s,o,i,a,g,w,l,u,U,C,F,h,d,f,H;return Q(this,function(Q){switch(Q.label){case 0:this.applyEffects(A.getEffects(4)),t=A.container,r=A.curves,B=t.styles,n=0,s=t.textNodes,Q.label=1;case 1:if(!(n<s.length))return[3,4];return o=s[n],[4,this.renderTextNode(o,B)];case 2:Q.sent(),Q.label=3;case 3:return n++,[3,1];case 4:if(!(t instanceof r_))return[3,8];Q.label=5;case 5:return Q.trys.push([5,7,,8]),[4,this.context.cache.match(t.src)];case 6:return i=Q.sent(),this.renderReplacedElement(t,r,i),[3,8];case 7:return Q.sent(),this.context.logger.error("Error loading image "+t.src),[3,8];case 8:if(t instanceof rq&&this.renderReplacedElement(t,r,t.canvas),!(t instanceof rj))return[3,12];Q.label=9;case 9:return Q.trys.push([9,11,,12]),[4,this.context.cache.match(t.svg)];case 10:return i=Q.sent(),this.renderReplacedElement(t,r,i),[3,12];case 11:return Q.sent(),this.context.logger.error("Error loading svg "+t.svg.substring(0,255)),[3,12];case 12:if(!(t instanceof r9&&t.tree))return[3,14];return[4,new e(this.context,{scale:this.options.scale,backgroundColor:t.backgroundColor,x:0,y:0,width:t.width,height:t.height}).render(t.tree)];case 13:g=Q.sent(),t.width&&t.height&&this.ctx.drawImage(g,0,0,t.width,t.height,t.bounds.left,t.bounds.top,t.bounds.width,t.bounds.height),Q.label=14;case 14:if(t instanceof r6&&(w=Math.min(t.bounds.width,t.bounds.height),t.type===r2?t.checked&&(this.ctx.save(),this.path([new nt(t.bounds.left+.39363*w,t.bounds.top+.79*w),new nt(t.bounds.left+.16*w,t.bounds.top+.5549*w),new nt(t.bounds.left+.27347*w,t.bounds.top+.44071*w),new nt(t.bounds.left+.39694*w,t.bounds.top+.5649*w),new nt(t.bounds.left+.72983*w,t.bounds.top+.23*w),new nt(t.bounds.left+.84*w,t.bounds.top+.34085*w),new nt(t.bounds.left+.39363*w,t.bounds.top+.79*w)]),this.ctx.fillStyle=A2(707406591),this.ctx.fill(),this.ctx.restore()):t.type===r3&&t.checked&&(this.ctx.save(),this.ctx.beginPath(),this.ctx.arc(t.bounds.left+w/2,t.bounds.top+w/2,w/4,0,2*Math.PI,!0),this.ctx.fillStyle=A2(707406591),this.ctx.fill(),this.ctx.restore())),nO(t)&&t.value.length){switch(u=(l=this.createFontStyle(B))[0],U=l[1],C=this.fontMetrics.getMetrics(u,U).baseline,this.ctx.font=u,this.ctx.fillStyle=A2(B.color),this.ctx.textBaseline="alphabetic",this.ctx.textAlign=nk(t.styles.textAlign),F=nK(t),h=0,t.styles.textAlign){case 1:h+=F.width/2;break;case 2:h+=F.width}d=F.add(h,0,0,-F.height/2+1),this.ctx.save(),this.path([new nt(F.left,F.top),new nt(F.left+F.width,F.top),new nt(F.left+F.width,F.top+F.height),new nt(F.left,F.top+F.height)]),this.ctx.clip(),this.renderTextWithLetterSpacing(new rG(t.value,d),B.letterSpacing,C),this.ctx.restore(),this.ctx.textBaseline="alphabetic",this.ctx.textAlign="left"}if(!tG(t.styles.display,2048))return[3,20];if(!(null!==t.styles.listStyleImage))return[3,19];if(0!==(f=t.styles.listStyleImage).type)return[3,18];i=void 0,H=f.url,Q.label=15;case 15:return Q.trys.push([15,17,,18]),[4,this.context.cache.match(H)];case 16:return i=Q.sent(),this.ctx.drawImage(i,t.bounds.left-(i.width+10),t.bounds.top),[3,18];case 17:return Q.sent(),this.context.logger.error("Error loading list-style-image "+H),[3,18];case 18:return[3,20];case 19:A.listValue&&-1!==t.styles.listStyleType&&(u=this.createFontStyle(B)[0],this.ctx.font=u,this.ctx.fillStyle=A2(B.color),this.ctx.textBaseline="middle",this.ctx.textAlign="right",F=new c(t.bounds.left,t.bounds.top+AZ(t.styles.paddingTop,t.bounds.width),t.bounds.width,tA(B.lineHeight,B.fontSize.number)/2+1),this.renderTextWithLetterSpacing(new rG(A.listValue,F),B.letterSpacing,tA(B.lineHeight,B.fontSize.number)/2+2),this.ctx.textBaseline="bottom",this.ctx.textAlign="left"),Q.label=20;case 20:return[2]}})})},e.prototype.renderStackContent=function(A){return i(this,void 0,void 0,function(){var e,t,r,B,n,s,o,i,a,c,g,w,l,u,U;return Q(this,function(Q){switch(Q.label){case 0:return tG(A.element.container.flags,16),[4,this.renderNodeBackgroundAndBorders(A.element)];case 1:Q.sent(),e=0,t=A.negativeZIndex,Q.label=2;case 2:if(!(e<t.length))return[3,5];return r=t[e],[4,this.renderStack(r)];case 3:Q.sent(),Q.label=4;case 4:return e++,[3,2];case 5:return[4,this.renderNodeContent(A.element)];case 6:Q.sent(),B=0,n=A.nonInlineLevel,Q.label=7;case 7:if(!(B<n.length))return[3,10];return r=n[B],[4,this.renderNode(r)];case 8:Q.sent(),Q.label=9;case 9:return B++,[3,7];case 10:s=0,o=A.nonPositionedFloats,Q.label=11;case 11:if(!(s<o.length))return[3,14];return r=o[s],[4,this.renderStack(r)];case 12:Q.sent(),Q.label=13;case 13:return s++,[3,11];case 14:i=0,a=A.nonPositionedInlineLevel,Q.label=15;case 15:if(!(i<a.length))return[3,18];return r=a[i],[4,this.renderStack(r)];case 16:Q.sent(),Q.label=17;case 17:return i++,[3,15];case 18:c=0,g=A.inlineLevel,Q.label=19;case 19:if(!(c<g.length))return[3,22];return r=g[c],[4,this.renderNode(r)];case 20:Q.sent(),Q.label=21;case 21:return c++,[3,19];case 22:w=0,l=A.zeroOrAutoZIndexOrTransformedOrOpacity,Q.label=23;case 23:if(!(w<l.length))return[3,26];return r=l[w],[4,this.renderStack(r)];case 24:Q.sent(),Q.label=25;case 25:return w++,[3,23];case 26:u=0,U=A.positiveZIndex,Q.label=27;case 27:if(!(u<U.length))return[3,30];return r=U[u],[4,this.renderStack(r)];case 28:Q.sent(),Q.label=29;case 29:return u++,[3,27];case 30:return[2]}})})},e.prototype.mask=function(A){this.ctx.beginPath(),this.ctx.moveTo(0,0),this.ctx.lineTo(this.canvas.width,0),this.ctx.lineTo(this.canvas.width,this.canvas.height),this.ctx.lineTo(0,this.canvas.height),this.ctx.lineTo(0,0),this.formatPath(A.slice(0).reverse()),this.ctx.closePath()},e.prototype.path=function(A){this.ctx.beginPath(),this.formatPath(A),this.ctx.closePath()},e.prototype.formatPath=function(A){var e=this;A.forEach(function(A,t){var r=nn(A)?A.start:A;0===t?e.ctx.moveTo(r.x,r.y):e.ctx.lineTo(r.x,r.y),nn(A)&&e.ctx.bezierCurveTo(A.startControl.x,A.startControl.y,A.endControl.x,A.endControl.y,A.end.x,A.end.y)})},e.prototype.renderRepeat=function(A,e,t,r){this.path(A),this.ctx.fillStyle=e,this.ctx.translate(t,r),this.ctx.fill(),this.ctx.translate(-t,-r)},e.prototype.resizeImage=function(A,e,t){if(A.width===e&&A.height===t)return A;var r,B=(null!==(r=this.canvas.ownerDocument)&&void 0!==r?r:document).createElement("canvas");return B.width=Math.max(1,e),B.height=Math.max(1,t),B.getContext("2d").drawImage(A,0,0,A.width,A.height,0,0,e,t),B},e.prototype.renderBackgroundImage=function(A){return i(this,void 0,void 0,function(){var e,t,r,B,n,s;return Q(this,function(s){switch(s.label){case 0:e=A.styles.backgroundImage.length-1,t=function(t){var B,n,s,o,i,a,c,g,w,l,u,U,C,F,h,d,f,H,p,E,I,y,K,m,L,v,b,D,x,M,S;return Q(this,function(Q){switch(Q.label){case 0:if(0!==t.type)return[3,5];B=void 0,n=t.url,Q.label=1;case 1:return Q.trys.push([1,3,,4]),[4,r.context.cache.match(n)];case 2:return B=Q.sent(),[3,4];case 3:return Q.sent(),r.context.logger.error("Error loading background-image "+n),[3,4];case 4:return B&&(o=(s=nm(A,e,[B.width,B.height,B.width/B.height]))[0],i=s[1],a=s[2],c=s[3],g=s[4],w=r.ctx.createPattern(r.resizeImage(B,c,g),"repeat"),r.renderRepeat(o,w,i,a)),[3,6];case 5:var T,G;1===t.type?(o=(l=nm(A,e,[null,null,null]))[0],i=l[1],a=l[2],c=l[3],g=l[4],U=(u=ec(t.angle,c,g))[0],C=u[1],F=u[2],h=u[3],d=u[4],(f=document.createElement("canvas")).width=c,f.height=g,p=(H=f.getContext("2d")).createLinearGradient(C,h,F,d),eQ(t.stops,U).forEach(function(A){return p.addColorStop(A.stop,A2(A.color))}),H.fillStyle=p,H.fillRect(0,0,c,g),c>0&&g>0&&(w=r.ctx.createPattern(f,"repeat"),r.renderRepeat(o,w,i,a))):2===(G=t).type&&(o=(E=nm(A,e,[null,null,null]))[0],I=E[1],y=E[2],c=E[3],g=E[4],K=0===t.position.length?[AJ]:t.position,i=AZ(K[0],c),a=AZ(K[K.length-1],g),L=(m=el(t,i,a,c,g))[0],v=m[1],L>0&&v>0&&(b=r.ctx.createRadialGradient(I+i,y+a,0,I+i,y+a,L),eQ(t.stops,2*L).forEach(function(A){return b.addColorStop(A.stop,A2(A.color))}),r.path(o),r.ctx.fillStyle=b,L!==v?(D=A.bounds.left+.5*A.bounds.width,x=A.bounds.top+.5*A.bounds.height,S=1/(M=v/L),r.ctx.save(),r.ctx.translate(D,x),r.ctx.transform(1,0,0,M,0,0),r.ctx.translate(-D,-x),r.ctx.fillRect(I,S*(y-x)+x,c,g*S),r.ctx.restore()):r.ctx.fill())),Q.label=6;case 6:return e--,[2]}})},r=this,B=0,n=A.styles.backgroundImage.slice(0).reverse(),s.label=1;case 1:if(!(B<n.length))return[3,4];return[5,t(n[B])];case 2:s.sent(),s.label=3;case 3:return B++,[3,1];case 4:return[2]}})})},e.prototype.renderSolidBorder=function(A,e,t){return i(this,void 0,void 0,function(){return Q(this,function(r){return this.path(nd(t,e)),this.ctx.fillStyle=A2(A),this.ctx.fill(),[2]})})},e.prototype.renderDoubleBorder=function(A,e,t,r){return i(this,void 0,void 0,function(){var B,n;return Q(this,function(s){switch(s.label){case 0:if(!(e<3))return[3,2];return[4,this.renderSolidBorder(A,t,r)];case 1:return s.sent(),[2];case 2:return B=nf(r,t),this.path(B),this.ctx.fillStyle=A2(A),this.ctx.fill(),n=nH(r,t),this.path(n),this.ctx.fill(),[2]}})})},e.prototype.renderNodeBackgroundAndBorders=function(A){return i(this,void 0,void 0,function(){var e,t,r,B,n,s,o,i,a=this;return Q(this,function(Q){switch(Q.label){case 0:if(this.applyEffects(A.getEffects(2)),t=!A1((e=A.container.styles).backgroundColor)||e.backgroundImage.length,r=[{style:e.borderTopStyle,color:e.borderTopColor,width:e.borderTopWidth},{style:e.borderRightStyle,color:e.borderRightColor,width:e.borderRightWidth},{style:e.borderBottomStyle,color:e.borderBottomColor,width:e.borderBottomWidth},{style:e.borderLeftStyle,color:e.borderLeftColor,width:e.borderLeftWidth}],B=nV(nD(e.backgroundClip,0),A.curves),!(t||e.boxShadow.length))return[3,2];return this.ctx.save(),this.path(B),this.ctx.clip(),A1(e.backgroundColor)||(this.ctx.fillStyle=A2(e.backgroundColor),this.ctx.fill()),[4,this.renderBackgroundImage(A.container)];case 1:Q.sent(),this.ctx.restore(),e.boxShadow.slice(0).reverse().forEach(function(e){a.ctx.save();var t,r,B,n,s,o=ni(A.curves),i=e.inset?0:1e4,Q=(r=-i+(e.inset?1:-1)*e.spread.number,B=(e.inset?1:-1)*e.spread.number,n=e.spread.number*(e.inset?-2:2),s=e.spread.number*(e.inset?-2:2),o.map(function(A,e){switch(e){case 0:return A.add(r,B);case 1:return A.add(r+n,B);case 2:return A.add(r+n,B+s);case 3:return A.add(r,B+s)}return A}));e.inset?(a.path(o),a.ctx.clip(),a.mask(Q)):(a.mask(o),a.ctx.clip(),a.path(Q)),a.ctx.shadowOffsetX=e.offsetX.number+i,a.ctx.shadowOffsetY=e.offsetY.number,a.ctx.shadowColor=A2(e.color),a.ctx.shadowBlur=e.blur.number,a.ctx.fillStyle=e.inset?A2(e.color):"rgba(0,0,0,1)",a.ctx.fill(),a.ctx.restore()}),Q.label=2;case 2:n=0,s=0,o=r,Q.label=3;case 3:if(!(s<o.length))return[3,13];if(!(0!==(i=o[s]).style&&!A1(i.color)&&i.width>0))return[3,11];if(2!==i.style)return[3,5];return[4,this.renderDashedDottedBorder(i.color,i.width,n,A.curves,2)];case 4:case 6:case 8:return Q.sent(),[3,11];case 5:if(3!==i.style)return[3,7];return[4,this.renderDashedDottedBorder(i.color,i.width,n,A.curves,3)];case 7:if(4!==i.style)return[3,9];return[4,this.renderDoubleBorder(i.color,i.width,n,A.curves)];case 9:return[4,this.renderSolidBorder(i.color,n,A.curves)];case 10:Q.sent(),Q.label=11;case 11:n++,Q.label=12;case 12:return s++,[3,3];case 13:return[2]}})})},e.prototype.renderDashedDottedBorder=function(A,e,t,r,B){return i(this,void 0,void 0,function(){var n,s,o,i,a,c,g,w,l,u,U,C,F,h,d,f;return Q(this,function(Q){return this.ctx.save(),n=np(r,t),s=nd(r,t),2===B&&(this.path(s),this.ctx.clip()),nn(s[0])?(o=s[0].start.x,i=s[0].start.y):(o=s[0].x,i=s[0].y),nn(s[1])?(a=s[1].end.x,c=s[1].end.y):(a=s[1].x,c=s[1].y),g=0===t||2===t?Math.abs(o-a):Math.abs(i-c),this.ctx.beginPath(),3===B?this.formatPath(n):this.formatPath(s.slice(0,2)),w=e<3?3*e:2*e,l=e<3?2*e:e,3===B&&(w=e,l=e),u=!0,g<=2*w?u=!1:g<=2*w+l?(U=g/(2*w+l),w*=U,l*=U):(C=Math.floor((g+l)/(w+l)),F=(g-C*w)/(C-1),l=(h=(g-(C+1)*w)/C)<=0||Math.abs(l-F)<Math.abs(l-h)?F:h),u&&(3===B?this.ctx.setLineDash([0,w+l]):this.ctx.setLineDash([w,l])),3===B?(this.ctx.lineCap="round",this.ctx.lineWidth=e):this.ctx.lineWidth=2*e+1.1,this.ctx.strokeStyle=A2(A),this.ctx.stroke(),this.ctx.setLineDash([]),2===B&&(nn(s[0])&&(d=s[3],f=s[0],this.ctx.beginPath(),this.formatPath([new nt(d.end.x,d.end.y),new nt(f.start.x,f.start.y)]),this.ctx.stroke()),nn(s[1])&&(d=s[1],f=s[2],this.ctx.beginPath(),this.formatPath([new nt(d.end.x,d.end.y),new nt(f.start.x,f.start.y)]),this.ctx.stroke())),this.ctx.restore(),[2]})})},e.prototype.render=function(A){return i(this,void 0,void 0,function(){var e;return Q(this,function(t){switch(t.label){case 0:return this.options.backgroundColor&&(this.ctx.fillStyle=A2(this.options.backgroundColor),this.ctx.fillRect(this.options.x,this.options.y,this.options.width,this.options.height)),e=nh(A),[4,this.renderStack(e)];case 1:return t.sent(),this.applyEffects([]),[2,this.canvas]}})})},e}(nT),nO=function(A){return A instanceof r7||A instanceof r8||A instanceof r6&&A.type!==r3&&A.type!==r2},nV=function(A,e){switch(A){case 0:return ni(e);case 2:var t;return[e.topLeftContentBox,e.topRightContentBox,e.bottomRightContentBox,e.bottomLeftContentBox];default:return nQ(e)}},nk=function(A){switch(A){case 1:return"center";case 2:return"right";default:return"left"}},nR=["-apple-system","system-ui"],nN=function(A){return/iPhone OS 15_(0|1)/.test(window.navigator.userAgent)?A.filter(function(A){return -1===nR.indexOf(A)}):A},nP=function(A){function e(e,t){var r=A.call(this,e,t)||this;return r.canvas=t.canvas?t.canvas:document.createElement("canvas"),r.ctx=r.canvas.getContext("2d"),r.options=t,r.canvas.width=Math.floor(t.width*t.scale),r.canvas.height=Math.floor(t.height*t.scale),r.canvas.style.width=t.width+"px",r.canvas.style.height=t.height+"px",r.ctx.scale(r.options.scale,r.options.scale),r.ctx.translate(-t.x,-t.y),r.context.logger.debug("EXPERIMENTAL ForeignObject renderer initialized ("+t.width+"x"+t.height+" at "+t.x+","+t.y+") with scale "+t.scale),r}return s(e,A),e.prototype.render=function(A){return i(this,void 0,void 0,function(){var e,t;return Q(this,function(r){switch(r.label){case 0:return e=rF(this.options.width*this.options.scale,this.options.height*this.options.scale,this.options.scale,this.options.scale,A),[4,nX(e)];case 1:return t=r.sent(),this.options.backgroundColor&&(this.ctx.fillStyle=A2(this.options.backgroundColor),this.ctx.fillRect(0,0,this.options.width*this.options.scale,this.options.height*this.options.scale)),this.ctx.drawImage(t,-this.options.x*this.options.scale,-this.options.y*this.options.scale),[2,this.canvas]}})})},e}(nT),nX=function(A){return new Promise(function(e,t){var r=new Image;r.onload=function(){e(r)},r.onerror=t,r.src="data:image/svg+xml;charset=utf-8,"+encodeURIComponent(new XMLSerializer().serializeToString(A))})},nJ=function(){function A(A){var e=A.id,t=A.enabled;this.id=e,this.enabled=t,this.start=Date.now()}return A.prototype.debug=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];this.enabled&&("undefined"!=typeof window&&window.console&&"function"==typeof console.debug?console.debug.apply(console,a([this.id,this.getTime()+"ms"],A)):this.info.apply(this,A))},A.prototype.getTime=function(){return Date.now()-this.start},A.prototype.info=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];this.enabled&&"undefined"!=typeof window&&window.console&&"function"==typeof console.info&&console.info.apply(console,a([this.id,this.getTime()+"ms"],A))},A.prototype.warn=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];this.enabled&&("undefined"!=typeof window&&window.console&&"function"==typeof console.warn?console.warn.apply(console,a([this.id,this.getTime()+"ms"],A)):this.info.apply(this,A))},A.prototype.error=function(){for(var A=[],e=0;e<arguments.length;e++)A[e]=arguments[e];this.enabled&&("undefined"!=typeof window&&window.console&&"function"==typeof console.error?console.error.apply(console,a([this.id,this.getTime()+"ms"],A)):this.info.apply(this,A))},A.instances={},A}(),nY=function(){function A(e,t){var r;this.windowBounds=t,this.instanceName="#"+A.instanceCount++,this.logger=new nJ({id:this.instanceName,enabled:e.logging}),this.cache=null!==(r=e.cache)&&void 0!==r?r:new B2(this,e)}return A.instanceCount=1,A}(),nW=function(A,e){return void 0===e&&(e={}),nZ(A,e)};"undefined"!=typeof window&&B1.setContext(window);var nZ=function(A,e){return i(void 0,void 0,void 0,function(){var t,r,B,n,s,i,a,l,u,U,C,F,h,d,f,H,p,E,I,y,K,m,L,v,b,D,x,M,S,T,G,O,V,k,R,N,P,X,J;return Q(this,function(Q){switch(Q.label){case 0:if(!A||"object"!=typeof A)return[2,Promise.reject("Invalid element provided as first argument")];if(!(t=A.ownerDocument))throw Error("Element is not attached to a Document");if(!(r=t.defaultView))throw Error("Document is not attached to a Window");if(B={allowTaint:null!==(L=e.allowTaint)&&void 0!==L&&L,imageTimeout:null!==(v=e.imageTimeout)&&void 0!==v?v:15e3,proxy:e.proxy,useCORS:null!==(b=e.useCORS)&&void 0!==b&&b},n=o({logging:null===(D=e.logging)||void 0===D||D,cache:e.cache},B),s={windowWidth:null!==(x=e.windowWidth)&&void 0!==x?x:r.innerWidth,windowHeight:null!==(M=e.windowHeight)&&void 0!==M?M:r.innerHeight,scrollX:null!==(S=e.scrollX)&&void 0!==S?S:r.pageXOffset,scrollY:null!==(T=e.scrollY)&&void 0!==T?T:r.pageYOffset},i=new c(s.scrollX,s.scrollY,s.windowWidth,s.windowHeight),a=new nY(n,i),l=null!==(G=e.foreignObjectRendering)&&void 0!==G&&G,u={allowTaint:null!==(O=e.allowTaint)&&void 0!==O&&O,onclone:e.onclone,ignoreElements:e.ignoreElements,inlineImages:l,copyStyles:l},a.logger.debug("Starting document clone with size "+i.width+"x"+i.height+" scrolled to "+-i.left+","+-i.top),!(C=(U=new Bk(a,A,u)).clonedReferenceElement))return[2,Promise.reject("Unable to find element in cloned iframe")];return[4,U.toIFrame(t,i)];case 1:var K;if(F=Q.sent(),d=(h=Bl(C)||"HTML"===(K=C).tagName?w(C.ownerDocument):g(a,C)).width,f=h.height,H=h.left,p=h.top,E=n_(a,C,e.backgroundColor),I={canvas:e.canvas,backgroundColor:E,scale:null!==(k=null!==(V=e.scale)&&void 0!==V?V:r.devicePixelRatio)&&void 0!==k?k:1,x:(null!==(R=e.x)&&void 0!==R?R:0)+H,y:(null!==(N=e.y)&&void 0!==N?N:0)+p,width:null!==(P=e.width)&&void 0!==P?P:Math.ceil(d),height:null!==(X=e.height)&&void 0!==X?X:Math.ceil(f)},!l)return[3,3];return a.logger.debug("Document cloned, using foreign object rendering"),[4,new nP(a,I).render(C)];case 2:return y=Q.sent(),[3,5];case 3:return a.logger.debug("Document cloned, element located at "+H+","+p+" with size "+d+"x"+f+" using computed rendering"),a.logger.debug("Starting DOM parsing"),m=Br(a,C),E===m.styles.backgroundColor&&(m.styles.backgroundColor=en.TRANSPARENT),a.logger.debug("Starting renderer for element at "+I.x+","+I.y+" with size "+I.width+"x"+I.height),[4,new nG(a,I).render(m)];case 4:y=Q.sent(),Q.label=5;case 5:return(null===(J=e.removeContainer)||void 0===J||J)&&!Bk.destroy(F)&&a.logger.error("Cannot detach cloned iframe as it is not in the DOM anymore"),a.logger.debug("Finished rendering"),[2,y]}})})},n_=function(A,e,t){var r=e.ownerDocument,B=r.documentElement?eB(A,getComputedStyle(r.documentElement).backgroundColor):en.TRANSPARENT,n=r.body?eB(A,getComputedStyle(r.body).backgroundColor):en.TRANSPARENT,s="string"==typeof t?eB(A,t):null===t?en.TRANSPARENT:4294967295;return e===r.documentElement?A1(B)?A1(n)?s:n:B:s};return nW},A.exports=e()}}]);